"""
Python module generated from Java source file java.util.ResourceBundle

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import InputStream
from java.io import UncheckedIOException
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import SoftReference
from java.lang.ref import WeakReference
from java.lang.reflect import Constructor
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Modifier
from java.net import JarURLConnection
from java.net import URL
from java.net import URLConnection
from java.security import AccessController
from java.security import PrivilegedAction
from java.security import PrivilegedActionException
from java.security import PrivilegedExceptionAction
from java.util import *
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from java.util.jar import JarEntry
from java.util.spi import ResourceBundleControlProvider
from java.util.spi import ResourceBundleProvider
from java.util.stream import Stream
from jdk.internal.access import JavaUtilResourceBundleAccess
from jdk.internal.access import SharedSecrets
from jdk.internal.loader import BootLoader
from jdk.internal.reflect import CallerSensitive
from jdk.internal.reflect import Reflection
from sun.security.action import GetPropertyAction
from sun.util.locale import BaseLocale
from sun.util.locale import LocaleObjectCache
from sun.util.resources import Bundles
from typing import Any, Callable, Iterable, Tuple


class ResourceBundle:
    """
    Resource bundles contain locale-specific objects.  When your program needs a
    locale-specific resource, a `String` for example, your program can
    load it from the resource bundle that is appropriate for the current user's
    locale. In this way, you can write program code that is largely independent
    of the user's locale isolating most, if not all, of the locale-specific
    information in resource bundles.
    
    
    This allows you to write programs that can:
    <UL>
    <LI> be easily localized, or translated, into different languages
    <LI> handle multiple locales at once
    <LI> be easily modified later to support even more locales
    </UL>
    
    <P>
    Resource bundles belong to families whose members share a common base
    name, but whose names also have additional components that identify
    their locales. For example, the base name of a family of resource
    bundles might be "MyResources". The family should have a default
    resource bundle which simply has the same name as its family -
    "MyResources" - and will be used as the bundle of last resort if a
    specific locale is not supported. The family can then provide as
    many locale-specific members as needed, for example a German one
    named "MyResources_de".
    
    <P>
    Each resource bundle in a family contains the same items, but the items have
    been translated for the locale represented by that resource bundle.
    For example, both "MyResources" and "MyResources_de" may have a
    `String` that's used on a button for canceling operations.
    In "MyResources" the `String` may contain "Cancel" and in
    "MyResources_de" it may contain "Abbrechen".
    
    <P>
    If there are different resources for different countries, you
    can make specializations: for example, "MyResources_de_CH" contains objects for
    the German language (de) in Switzerland (CH). If you want to only
    modify some of the resources
    in the specialization, you can do so.
    
    <P>
    When your program needs a locale-specific object, it loads
    the `ResourceBundle` class using the
    .getBundle(java.lang.String, java.util.Locale) getBundle
    method:
    <blockquote>
    ```
    ResourceBundle myResources =
         ResourceBundle.getBundle("MyResources", currentLocale);
    ```
    </blockquote>
    
    <P>
    Resource bundles contain key/value pairs. The keys uniquely
    identify a locale-specific object in the bundle. Here's an
    example of a `ListResourceBundle` that contains
    two key/value pairs:
    <blockquote>
    ```
    public class MyResources extends ListResourceBundle {
        protected Object[][] getContents() {
            return new Object[][] {
                // LOCALIZE THE SECOND STRING OF EACH ARRAY (e.g., "OK")
                {"OkKey", "OK"},
                {"CancelKey", "Cancel"},
                // END OF MATERIAL TO LOCALIZE
           };
        }
    }
    ```
    </blockquote>
    Keys are always `String`s.
    In this example, the keys are "OkKey" and "CancelKey".
    In the above example, the values
    are also `String`s--"OK" and "Cancel"--but
    they don't have to be. The values can be any type of object.
    
    <P>
    You retrieve an object from resource bundle using the appropriate
    getter method. Because "OkKey" and "CancelKey"
    are both strings, you would use `getString` to retrieve them:
    <blockquote>
    ```
    button1 = new Button(myResources.getString("OkKey"));
    button2 = new Button(myResources.getString("CancelKey"));
    ```
    </blockquote>
    The getter methods all require the key as an argument and return
    the object if found. If the object is not found, the getter method
    throws a `MissingResourceException`.
    
    <P>
    Besides `getString`, `ResourceBundle` also provides
    a method for getting string arrays, `getStringArray`,
    as well as a generic `getObject` method for any other
    type of object. When using `getObject`, you'll
    have to cast the result to the appropriate type. For example:
    <blockquote>
    ```
    int[] myIntegers = (int[]) myResources.getObject("intList");
    ```
    </blockquote>
    
    <P>
    The Java Platform provides two subclasses of `ResourceBundle`,
    `ListResourceBundle` and `PropertyResourceBundle`,
    that provide a fairly simple way to create resources.
    As you saw briefly in a previous example, `ListResourceBundle`
    manages its resource as a list of key/value pairs.
    `PropertyResourceBundle` uses a properties file to manage
    its resources.
    
    
    If `ListResourceBundle` or `PropertyResourceBundle`
    do not suit your needs, you can write your own `ResourceBundle`
    subclass.  Your subclasses must override two methods: `handleGetObject`
    and `getKeys()`.
    
    
    The implementation of a `ResourceBundle` subclass must be thread-safe
    if it's simultaneously used by multiple threads. The default implementations
    of the non-abstract methods in this class, and the methods in the direct
    known concrete subclasses `ListResourceBundle` and
    `PropertyResourceBundle` are thread-safe.
    
    <h2><a id="resource-bundle-modules">Resource Bundles and Named Modules</a></h2>
    
    Resource bundles can be deployed in modules in the following ways:
    
    <h3>Resource bundles together with an application</h3>
    
    Resource bundles can be deployed together with an application in the same
    module.  In that case, the resource bundles are loaded
    by code in the module by calling the .getBundle(String)
    or .getBundle(String, Locale) method.
    
    <h3><a id="service-providers">Resource bundles as service providers</a></h3>
    
    Resource bundles can be deployed in one or more *service provider modules*
    and they can be located using ServiceLoader.
    A ResourceBundleProvider service interface or class must be
    defined. The caller module declares that it uses the service, the service
    provider modules declare that they provide implementations of the service.
    Refer to ResourceBundleProvider for developing resource bundle
    services and deploying resource bundle providers.
    The module obtaining the resource bundle can be a resource bundle
    provider itself; in which case this module only locates the resource bundle
    via service provider mechanism.
    
    A ResourceBundleProvider resource bundle provider can
    provide resource bundles in any format such XML which replaces the need
    of Control ResourceBundle.Control.
    
    <h3><a id="other-modules">Resource bundles in other modules and class path</a></h3>
    
    Resource bundles in a named module may be *encapsulated* so that
    it cannot be located by code in other modules.  Resource bundles
    in unnamed modules and class path are open for any module to access.
    Resource bundle follows the resource encapsulation rules as specified
    in Module.getResourceAsStream(String).
    
    The `getBundle` factory methods with no `Control` parameter
    locate and load resource bundles from
    ResourceBundleProvider service providers.
    It may continue the search as if calling Module.getResourceAsStream(String)
    to find the named resource from a given module and calling
    ClassLoader.getResourceAsStream(String); refer to
    the specification of the `getBundle` method for details.
    Only non-encapsulated resource bundles of "`java.class`"
    or "`java.properties`" format are searched.
    
    If the caller module is a
    <a href="/java.base/java/util/spi/ResourceBundleProvider.html#obtain-resource-bundle">
    resource bundle provider</a>, it does not fall back to the
    class loader search.
    
    <h3>Resource bundles in automatic modules</h3>
    
    A common format of resource bundles is in PropertyResourceBundle
    .properties file format.  Typically `.properties` resource bundles
    are packaged in a JAR file.  Resource bundle only JAR file can be readily
    deployed as an <a href="/java.base/java/lang/module/ModuleFinder.html#automatic-modules">
    automatic module</a>.  For example, if the JAR file contains the
    entry "`p/q/Foo_ja.properties`" and no `.class` entry,
    when resolved and defined as an automatic module, no package is derived
    for this module.  This allows resource bundles in `.properties`
    format packaged in one or more JAR files that may contain entries
    in the same directory and can be resolved successfully as
    automatic modules.
    
    <h3>ResourceBundle.Control</h3>
    
    The ResourceBundle.Control class provides information necessary
    to perform the bundle loading process by the `getBundle`
    factory methods that take a `ResourceBundle.Control`
    instance. You can implement your own subclass in order to enable
    non-standard resource bundle formats, change the search strategy, or
    define caching parameters. Refer to the descriptions of the class and the
    .getBundle(String, Locale, ClassLoader, Control) getBundle
    factory method for details.
    
     ResourceBundle.Control is designed for an application deployed
    in an unnamed module, for example to support resource bundles in
    non-standard formats or package localized resources in a non-traditional
    convention. ResourceBundleProvider is the replacement for
    `ResourceBundle.Control` when migrating to modules.
    `UnsupportedOperationException` will be thrown when a factory
    method that takes the `ResourceBundle.Control` parameter is called.
    
    <a id="modify_default_behavior">For the `getBundle` factory</a>
    methods that take no Control instance, their <a
    href="#default_behavior"> default behavior</a> of resource bundle loading
    can be modified with custom ResourceBundleControlProvider implementations.
    If any of the
    providers provides a Control for the given base name, that Control will be used instead of the default Control. If there is
    more than one service provider for supporting the same base name,
    the first one returned from ServiceLoader will be used.
    A custom Control implementation is ignored by named modules.
    
    <h2>Cache Management</h2>
    
    Resource bundle instances created by the `getBundle` factory
    methods are cached by default, and the factory methods return the same
    resource bundle instance multiple times if it has been
    cached. `getBundle` clients may clear the cache, manage the
    lifetime of cached resource bundle instances using time-to-live values,
    or specify not to cache resource bundle instances. Refer to the
    descriptions of the .getBundle(String, Locale, ClassLoader,
    Control) {@code getBundle factory method}, .clearCache(ClassLoader) clearCache, Control.getTimeToLive(String, Locale)
    ResourceBundle.Control.getTimeToLive, and Control.needsReload(String, Locale, String, ClassLoader, ResourceBundle,
    long) ResourceBundle.Control.needsReload for details.
    
    <h2>Example</h2>
    
    The following is a very simple example of a `ResourceBundle`
    subclass, `MyResources`, that manages two resources (for a larger number of
    resources you would probably use a `Map`).
    Notice that you don't need to supply a value if
    a "parent-level" `ResourceBundle` handles the same
    key with the same value (as for the okKey below).
    <blockquote>
    ```
    // default (English language, United States)
    public class MyResources extends ResourceBundle {
        public Object handleGetObject(String key) {
            if (key.equals("okKey")) return "Ok";
            if (key.equals("cancelKey")) return "Cancel";
            return null;
        }
    
        public Enumeration&lt;String&gt; getKeys() {
            return Collections.enumeration(keySet());
        }
    
        // Overrides handleKeySet() so that the getKeys() implementation
        // can rely on the keySet() value.
        protected Set&lt;String&gt; handleKeySet() {
            return new HashSet&lt;String&gt;(Arrays.asList("okKey", "cancelKey"));
        }
    }
    
    // German language
    public class MyResources_de extends MyResources {
        public Object handleGetObject(String key) {
            // don't need okKey, since parent level handles it.
            if (key.equals("cancelKey")) return "Abbrechen";
            return null;
        }
    
        protected Set&lt;String&gt; handleKeySet() {
            return new HashSet&lt;String&gt;(Arrays.asList("cancelKey"));
        }
    }
    ```
    </blockquote>
    You do not have to restrict yourself to using a single family of
    `ResourceBundle`s. For example, you could have a set of bundles for
    exception messages, `ExceptionResources`
    (`ExceptionResources_fr`, `ExceptionResources_de`, ...),
    and one for widgets, `WidgetResource` (`WidgetResources_fr`,
    `WidgetResources_de`, ...); breaking up the resources however you like.

    See
    - ResourceBundleProvider

    Since
    - 1.1

    Unknown Tags
    - 9
    """

    def __init__(self):
        """
        Sole constructor.  (For invocation by subclass constructors, typically
        implicit.)
        """
        ...


    def getBaseBundleName(self) -> str:
        """
        Returns the base name of this bundle, if known, or `null` if unknown.
        
        If not null, then this is the value of the `baseName` parameter
        that was passed to the `ResourceBundle.getBundle(...)` method
        when the resource bundle was loaded.

        Returns
        - The base name of the resource bundle, as provided to and expected
        by the `ResourceBundle.getBundle(...)` methods.

        See
        - .getBundle(java.lang.String, java.util.Locale, java.lang.ClassLoader)

        Since
        - 1.8
        """
        ...


    def getString(self, key: str) -> str:
        """
        Gets a string for the given key from this resource bundle or one of its parents.
        Calling this method is equivalent to calling
        <blockquote>
        `(String) .getObject(java.lang.String) getObject(key)`.
        </blockquote>

        Arguments
        - key: the key for the desired string

        Returns
        - the string for the given key

        Raises
        - NullPointerException: if `key` is `null`
        - MissingResourceException: if no object for the given key can be found
        - ClassCastException: if the object found for the given key is not a string
        """
        ...


    def getStringArray(self, key: str) -> list[str]:
        """
        Gets a string array for the given key from this resource bundle or one of its parents.
        Calling this method is equivalent to calling
        <blockquote>
        `(String[]) .getObject(java.lang.String) getObject(key)`.
        </blockquote>

        Arguments
        - key: the key for the desired string array

        Returns
        - the string array for the given key

        Raises
        - NullPointerException: if `key` is `null`
        - MissingResourceException: if no object for the given key can be found
        - ClassCastException: if the object found for the given key is not a string array
        """
        ...


    def getObject(self, key: str) -> "Object":
        """
        Gets an object for the given key from this resource bundle or one of its parents.
        This method first tries to obtain the object from this resource bundle using
        .handleGetObject(java.lang.String) handleGetObject.
        If not successful, and the parent resource bundle is not null,
        it calls the parent's `getObject` method.
        If still not successful, it throws a MissingResourceException.

        Arguments
        - key: the key for the desired object

        Returns
        - the object for the given key

        Raises
        - NullPointerException: if `key` is `null`
        - MissingResourceException: if no object for the given key can be found
        """
        ...


    def getLocale(self) -> "Locale":
        """
        Returns the locale of this resource bundle. This method can be used after a
        call to getBundle() to determine whether the resource bundle returned really
        corresponds to the requested locale or is a fallback.

        Returns
        - the locale of this resource bundle
        """
        ...


    @staticmethod
    def getBundle(baseName: str) -> "ResourceBundle":
        """
        Gets a resource bundle using the specified base name, the default locale,
        and the caller module. Calling this method is equivalent to calling
        <blockquote>
        `getBundle(baseName, Locale.getDefault(), callerModule)`,
        </blockquote>

        Arguments
        - baseName: the base name of the resource bundle, a fully qualified class name

        Returns
        - a resource bundle for the given base name and the default locale

        Raises
        - java.lang.NullPointerException: if `baseName` is `null`
        - MissingResourceException: if no resource bundle for the specified base name can be found

        See
        - <a href=".resource-bundle-modules">Resource Bundles and Named Modules</a>
        """
        ...


    @staticmethod
    def getBundle(baseName: str, control: "Control") -> "ResourceBundle":
        """
        Returns a resource bundle using the specified base name, the
        default locale and the specified control. Calling this method
        is equivalent to calling
        ```
        getBundle(baseName, Locale.getDefault(),
                  this.getClass().getClassLoader(), control),
        ```
        except that `getClassLoader()` is run with the security
        privileges of `ResourceBundle`.  See .getBundle(String, Locale, ClassLoader, Control) getBundle for the
        complete description of the resource bundle loading process with a
        `ResourceBundle.Control`.

        Arguments
        - baseName: the base name of the resource bundle, a fully qualified class
               name
        - control: the control which gives information for the resource bundle
               loading process

        Returns
        - a resource bundle for the given base name and the default locale

        Raises
        - NullPointerException: if `baseName` or `control` is
                `null`
        - MissingResourceException: if no resource bundle for the specified base name can be found
        - IllegalArgumentException: if the given `control` doesn't perform properly
                (e.g., `control.getCandidateLocales` returns null.)
                Note that validation of `control` is performed as
                needed.
        - UnsupportedOperationException: if this method is called in a named module

        Since
        - 1.6

        Unknown Tags
        - 9
        """
        ...


    @staticmethod
    def getBundle(baseName: str, locale: "Locale") -> "ResourceBundle":
        """
        Gets a resource bundle using the specified base name and locale,
        and the caller module. Calling this method is equivalent to calling
        <blockquote>
        `getBundle(baseName, locale, callerModule)`,
        </blockquote>

        Arguments
        - baseName: the base name of the resource bundle, a fully qualified class name
        - locale: the locale for which a resource bundle is desired

        Returns
        - a resource bundle for the given base name and locale

        Raises
        - NullPointerException: if `baseName` or `locale` is `null`
        - MissingResourceException: if no resource bundle for the specified base name can be found

        See
        - <a href=".resource-bundle-modules">Resource Bundles and Named Modules</a>
        """
        ...


    @staticmethod
    def getBundle(baseName: str, module: "Module") -> "ResourceBundle":
        """
        Gets a resource bundle using the specified base name and the default locale
        on behalf of the specified module. This method is equivalent to calling
        <blockquote>
        `getBundle(baseName, Locale.getDefault(), module)`
        </blockquote>

        Arguments
        - baseName: the base name of the resource bundle,
                        a fully qualified class name
        - module: the module for which the resource bundle is searched

        Returns
        - a resource bundle for the given base name and the default locale

        Raises
        - NullPointerException: if `baseName` or `module` is `null`
        - SecurityException: if a security manager exists and the caller is not the specified
                module and doesn't have `RuntimePermission("getClassLoader")`
        - MissingResourceException: if no resource bundle for the specified base name can be found in the
                specified module

        See
        - <a href=".resource-bundle-modules">Resource Bundles and Named Modules</a>

        Since
        - 9
        """
        ...


    @staticmethod
    def getBundle(baseName: str, targetLocale: "Locale", module: "Module") -> "ResourceBundle":
        """
        Gets a resource bundle using the specified base name and locale
        on behalf of the specified module.
        
         Resource bundles in named modules may be encapsulated.  When
        the resource bundle is loaded from a
        ResourceBundleProvider service provider, the caller module
        must have an appropriate *uses* clause in its *module descriptor*
        to declare that the module uses of ResourceBundleProvider
        for the named resource bundle.
        Otherwise, it will load the resource bundles that are local in the
        given module as if calling Module.getResourceAsStream(String)
        or that are visible to the class loader of the given module
        as if calling ClassLoader.getResourceAsStream(String).
        When the resource bundle is loaded from the specified module, it is
        subject to the encapsulation rules specified by
        Module.getResourceAsStream Module.getResourceAsStream.
        
        
        If the given `module` is an unnamed module, then this method is
        equivalent to calling .getBundle(String, Locale, ClassLoader)
        getBundle(baseName, targetLocale, module.getClassLoader() to load
        resource bundles that are visible to the class loader of the given
        unnamed module. Custom java.util.spi.ResourceBundleControlProvider
        implementations, if present, will only be invoked if the specified
        module is an unnamed module.

        Arguments
        - baseName: the base name of the resource bundle,
                        a fully qualified class name
        - targetLocale: the locale for which a resource bundle is desired
        - module: the module for which the resource bundle is searched

        Returns
        - a resource bundle for the given base name and locale in the module

        Raises
        - NullPointerException: if `baseName`, `targetLocale`, or `module` is
                `null`
        - SecurityException: if a security manager exists and the caller is not the specified
                module and doesn't have `RuntimePermission("getClassLoader")`
        - MissingResourceException: if no resource bundle for the specified base name and locale can
                be found in the specified `module`

        See
        - <a href=".resource-bundle-modules">Resource Bundles and Named Modules</a>

        Since
        - 9
        """
        ...


    @staticmethod
    def getBundle(baseName: str, targetLocale: "Locale", control: "Control") -> "ResourceBundle":
        """
        Returns a resource bundle using the specified base name, target
        locale and control, and the caller's class loader. Calling this
        method is equivalent to calling
        ```
        getBundle(baseName, targetLocale, this.getClass().getClassLoader(),
                  control),
        ```
        except that `getClassLoader()` is run with the security
        privileges of `ResourceBundle`.  See .getBundle(String, Locale, ClassLoader, Control) getBundle for the
        complete description of the resource bundle loading process with a
        `ResourceBundle.Control`.

        Arguments
        - baseName: the base name of the resource bundle, a fully qualified
               class name
        - targetLocale: the locale for which a resource bundle is desired
        - control: the control which gives information for the resource
               bundle loading process

        Returns
        - a resource bundle for the given base name and a
                `Locale` in `locales`

        Raises
        - NullPointerException: if `baseName`, `locales` or
                `control` is `null`
        - MissingResourceException: if no resource bundle for the specified base name in any
                of the `locales` can be found.
        - IllegalArgumentException: if the given `control` doesn't perform properly
                (e.g., `control.getCandidateLocales` returns null.)
                Note that validation of `control` is performed as
                needed.
        - UnsupportedOperationException: if this method is called in a named module

        Since
        - 1.6

        Unknown Tags
        - 9
        """
        ...


    @staticmethod
    def getBundle(baseName: str, locale: "Locale", loader: "ClassLoader") -> "ResourceBundle":
        """
        Gets a resource bundle using the specified base name, locale, and class
        loader.
        
        When this method is called from a named module and the given
        loader is the class loader of the caller module, this is equivalent
        to calling:
        <blockquote>```
        getBundle(baseName, targetLocale, callerModule)
        ```</blockquote>
        
        otherwise, this is equivalent to calling:
        <blockquote>```
        getBundle(baseName, targetLocale, loader, control)
        ```</blockquote>
        where `control` is the default instance of Control unless
        a `Control` instance is provided by
        ResourceBundleControlProvider SPI.  Refer to the
        description of <a href="#modify_default_behavior">modifying the default
        behavior</a>. The following describes the default behavior.
        
        
        **<a id="default_behavior">Resource Bundle Search and Loading Strategy</a>**
        
        `getBundle` uses the base name, the specified locale, and
        the default locale (obtained from java.util.Locale.getDefault()
        Locale.getDefault) to generate a sequence of <a
        id="candidates">*candidate bundle names*</a>.  If the specified
        locale's language, script, country, and variant are all empty strings,
        then the base name is the only candidate bundle name.  Otherwise, a list
        of candidate locales is generated from the attribute values of the
        specified locale (language, script, country and variant) and appended to
        the base name.  Typically, this will look like the following:
        
        ```
            baseName + "_" + language + "_" + script + "_" + country + "_" + variant
            baseName + "_" + language + "_" + script + "_" + country
            baseName + "_" + language + "_" + script
            baseName + "_" + language + "_" + country + "_" + variant
            baseName + "_" + language + "_" + country
            baseName + "_" + language
        ```
        
        Candidate bundle names where the final component is an empty string
        are omitted, along with the underscore.  For example, if country is an
        empty string, the second and the fifth candidate bundle names above
        would be omitted.  Also, if script is an empty string, the candidate names
        including script are omitted.  For example, a locale with language "de"
        and variant "JAVA" will produce candidate names with base name
        "MyResource" below.
        
        ```
            MyResource_de__JAVA
            MyResource_de
        ```
        
        In the case that the variant contains one or more underscores ('_'), a
        sequence of bundle names generated by truncating the last underscore and
        the part following it is inserted after a candidate bundle name with the
        original variant.  For example, for a locale with language "en", script
        "Latn, country "US" and variant "WINDOWS_VISTA", and bundle base name
        "MyResource", the list of candidate bundle names below is generated:
        
        ```
        MyResource_en_Latn_US_WINDOWS_VISTA
        MyResource_en_Latn_US_WINDOWS
        MyResource_en_Latn_US
        MyResource_en_Latn
        MyResource_en_US_WINDOWS_VISTA
        MyResource_en_US_WINDOWS
        MyResource_en_US
        MyResource_en
        ```
        
        <blockquote>**Note:** For some `Locale`s, the list of
        candidate bundle names contains extra names, or the order of bundle names
        is slightly modified.  See the description of the default implementation
        of Control.getCandidateLocales(String, Locale)
        getCandidateLocales for details.</blockquote>
        
        `getBundle` then iterates over the candidate bundle names
        to find the first one for which it can *instantiate* an actual
        resource bundle. It uses the default controls' Control.getFormats
        getFormats method, which generates two bundle names for each generated
        name, the first a class name and the second a properties file name. For
        each candidate bundle name, it attempts to create a resource bundle:
        
        - First, it attempts to load a class using the generated class name.
        If such a class can be found and loaded using the specified class
        loader, is assignment compatible with ResourceBundle, is accessible from
        ResourceBundle, and can be instantiated, `getBundle` creates a
        new instance of this class and uses it as the *result resource
        bundle*.
        
        - Otherwise, `getBundle` attempts to locate a property
        resource file using the generated properties file name.  It generates a
        path name from the candidate bundle name by replacing all "." characters
        with "/" and appending the string ".properties".  It attempts to find a
        "resource" with this name using java.lang.ClassLoader.getResource(java.lang.String)
        ClassLoader.getResource.  (Note that a "resource" in the sense of
        `getResource` has nothing to do with the contents of a
        resource bundle, it is just a container of data, such as a file.)  If it
        finds a "resource", it attempts to create a new PropertyResourceBundle instance from its contents.  If successful, this
        instance becomes the *result resource bundle*.  
        
        This continues until a result resource bundle is instantiated or the
        list of candidate bundle names is exhausted.  If no matching resource
        bundle is found, the default control's Control.getFallbackLocale
        getFallbackLocale method is called, which returns the current default
        locale.  A new sequence of candidate locale names is generated using this
        locale and searched again, as above.
        
        If still no result bundle is found, the base name alone is looked up. If
        this still fails, a `MissingResourceException` is thrown.
        
        <a id="parent_chain"> Once a result resource bundle has been found,
        its *parent chain* is instantiated</a>.  If the result bundle already
        has a parent (perhaps because it was returned from a cache) the chain is
        complete.
        
        Otherwise, `getBundle` examines the remainder of the
        candidate locale list that was used during the pass that generated the
        result resource bundle.  (As before, candidate bundle names where the
        final component is an empty string are omitted.)  When it comes to the
        end of the candidate list, it tries the plain bundle name.  With each of the
        candidate bundle names it attempts to instantiate a resource bundle (first
        looking for a class and then a properties file, as described above).
        
        Whenever it succeeds, it calls the previously instantiated resource
        bundle's .setParent(java.util.ResourceBundle) setParent method
        with the new resource bundle.  This continues until the list of names
        is exhausted or the current bundle already has a non-null parent.
        
        Once the parent chain is complete, the bundle is returned.
        
        **Note:** `getBundle` caches instantiated resource
        bundles and might return the same resource bundle instance multiple times.
        
        **Note:**The `baseName` argument should be a fully
        qualified class name. However, for compatibility with earlier versions,
        Java SE Runtime Environments do not verify this, and so it is
        possible to access `PropertyResourceBundle`s by specifying a
        path name (using "/") instead of a fully qualified class name (using
        ".").
        
        <a id="default_behavior_example">
        <strong>Example:</strong></a>
        
        The following class and property files are provided:
        
            - MyResources.class
            - MyResources.properties
            - MyResources_fr.properties
            - MyResources_fr_CH.class
            - MyResources_fr_CH.properties
            - MyResources_en.properties
            - MyResources_es_ES.class
        
        
        The contents of all files are valid (that is, public non-abstract
        subclasses of `ResourceBundle` for the ".class" files,
        syntactically correct ".properties" files).  The default locale is
        `Locale("en", "GB")`.
        
        Calling `getBundle` with the locale arguments below will
        instantiate resource bundles as follows:
        
        <table class="striped">
        <caption style="display:none">getBundle() locale to resource bundle mapping</caption>
        <thead>
        <tr><th scope="col">Locale</th><th scope="col">Resource bundle</th></tr>
        </thead>
        <tbody>
        <tr><th scope="row">Locale("fr", "CH")</th><td>MyResources_fr_CH.class, parent MyResources_fr.properties, parent MyResources.class</td></tr>
        <tr><th scope="row">Locale("fr", "FR")</th><td>MyResources_fr.properties, parent MyResources.class</td></tr>
        <tr><th scope="row">Locale("de", "DE")</th><td>MyResources_en.properties, parent MyResources.class</td></tr>
        <tr><th scope="row">Locale("en", "US")</th><td>MyResources_en.properties, parent MyResources.class</td></tr>
        <tr><th scope="row">Locale("es", "ES")</th><td>MyResources_es_ES.class, parent MyResources.class</td></tr>
        </tbody>
        </table>
        
        The file MyResources_fr_CH.properties is never used because it is
        hidden by the MyResources_fr_CH.class. Likewise, MyResources.properties
        is also hidden by MyResources.class.

        Arguments
        - baseName: the base name of the resource bundle, a fully qualified class name
        - locale: the locale for which a resource bundle is desired
        - loader: the class loader from which to load the resource bundle

        Returns
        - a resource bundle for the given base name and locale

        Raises
        - java.lang.NullPointerException: if `baseName`, `locale`, or `loader` is `null`
        - MissingResourceException: if no resource bundle for the specified base name can be found

        See
        - <a href=".resource-bundle-modules">Resource Bundles and Named Modules</a>

        Since
        - 1.2

        Unknown Tags
        - If the caller module is a named module and the given
        `loader` is the caller module's class loader, this method is
        equivalent to `getBundle(baseName, locale)`; otherwise, it may not
        find resource bundles from named modules.
        Use .getBundle(String, Locale, Module) to load resource bundles
        on behalf on a specific module instead.
        - 9
        """
        ...


    @staticmethod
    def getBundle(baseName: str, targetLocale: "Locale", loader: "ClassLoader", control: "Control") -> "ResourceBundle":
        """
        Returns a resource bundle using the specified base name, target
        locale, class loader and control. Unlike the .getBundle(String, Locale, ClassLoader) getBundle
        factory methods with no `control` argument, the given
        `control` specifies how to locate and instantiate resource
        bundles. Conceptually, the bundle loading process with the given
        `control` is performed in the following steps.
        
        <ol>
        - This factory method looks up the resource bundle in the cache for
        the specified `baseName`, `targetLocale` and
        `loader`.  If the requested resource bundle instance is
        found in the cache and the time-to-live periods of the instance and
        all of its parent instances have not expired, the instance is returned
        to the caller. Otherwise, this factory method proceeds with the
        loading process below.
        
        - The ResourceBundle.Control.getFormats(String)
        control.getFormats method is called to get resource bundle formats
        to produce bundle or resource names. The strings
        `"java.class"` and `"java.properties"`
        designate class-based and PropertyResourceBundle
        property-based resource bundles, respectively. Other strings
        starting with `"java."` are reserved for future extensions
        and must not be used for application-defined formats. Other strings
        designate application-defined formats.
        
        - The ResourceBundle.Control.getCandidateLocales(String,
        Locale) control.getCandidateLocales method is called with the target
        locale to get a list of *candidate `Locale`s* for
        which resource bundles are searched.
        
        - The ResourceBundle.Control.newBundle(String, Locale,
        String, ClassLoader, boolean) control.newBundle method is called to
        instantiate a `ResourceBundle` for the base bundle name, a
        candidate locale, and a format. (Refer to the note on the cache
        lookup below.) This step is iterated over all combinations of the
        candidate locales and formats until the `newBundle` method
        returns a `ResourceBundle` instance or the iteration has
        used up all the combinations. For example, if the candidate locales
        are `Locale("de", "DE")`, `Locale("de")` and
        `Locale("")` and the formats are `"java.class"`
        and `"java.properties"`, then the following is the
        sequence of locale-format combinations to be used to call
        `control.newBundle`.
        
        <table class=striped style="width: 50%; text-align: left; margin-left: 40px;">
        <caption style="display:none">locale-format combinations for newBundle</caption>
        <thead>
        <tr>
        <th scope="col">Index</th>
        <th scope="col">`Locale`</th>
        <th scope="col">`format`</th>
        </tr>
        </thead>
        <tbody>
        <tr>
        <th scope="row">1</th>
        <td>`Locale("de", "DE")`</td>
        <td>`java.class`</td>
        </tr>
        <tr>
        <th scope="row">2</th>
        <td>`Locale("de", "DE")`</td>
        <td>`java.properties`</td>
        </tr>
        <tr>
        <th scope="row">3</th>
        <td>`Locale("de")`</td>
        <td>`java.class`</td>
        </tr>
        <tr>
        <th scope="row">4</th>
        <td>`Locale("de")`</td>
        <td>`java.properties`</td>
        </tr>
        <tr>
        <th scope="row">5</th>
        <td>`Locale("")`</td>
        <td>`java.class`</td>
        </tr>
        <tr>
        <th scope="row">6</th>
        <td>`Locale("")`</td>
        <td>`java.properties`</td>
        </tr>
        </tbody>
        </table>
        
        
        - If the previous step has found no resource bundle, proceed to
        Step 6. If a bundle has been found that is a base bundle (a bundle
        for `Locale("")`), and the candidate locale list only contained
        `Locale("")`, return the bundle to the caller. If a bundle
        has been found that is a base bundle, but the candidate locale list
        contained locales other than Locale(""), put the bundle on hold and
        proceed to Step 6. If a bundle has been found that is not a base
        bundle, proceed to Step 7.
        
        - The ResourceBundle.Control.getFallbackLocale(String,
        Locale) control.getFallbackLocale method is called to get a fallback
        locale (alternative to the current target locale) to try further
        finding a resource bundle. If the method returns a non-null locale,
        it becomes the next target locale and the loading process starts over
        from Step 3. Otherwise, if a base bundle was found and put on hold in
        a previous Step 5, it is returned to the caller now. Otherwise, a
        MissingResourceException is thrown.
        
        - At this point, we have found a resource bundle that's not the
        base bundle. If this bundle set its parent during its instantiation,
        it is returned to the caller. Otherwise, its <a
        href="./ResourceBundle.html#parent_chain">parent chain</a> is
        instantiated based on the list of candidate locales from which it was
        found. Finally, the bundle is returned to the caller.
        </ol>
        
        During the resource bundle loading process above, this factory
        method looks up the cache before calling the Control.newBundle(String, Locale, String, ClassLoader, boolean)
        control.newBundle method.  If the time-to-live period of the
        resource bundle found in the cache has expired, the factory method
        calls the ResourceBundle.Control.needsReload(String, Locale,
        String, ClassLoader, ResourceBundle, long) control.needsReload
        method to determine whether the resource bundle needs to be reloaded.
        If reloading is required, the factory method calls
        `control.newBundle` to reload the resource bundle.  If
        `control.newBundle` returns `null`, the factory
        method puts a dummy resource bundle in the cache as a mark of
        nonexistent resource bundles in order to avoid lookup overhead for
        subsequent requests. Such dummy resource bundles are under the same
        expiration control as specified by `control`.
        
        All resource bundles loaded are cached by default. Refer to
        Control.getTimeToLive(String,Locale)
        control.getTimeToLive for details.
        
        The following is an example of the bundle loading process with the
        default `ResourceBundle.Control` implementation.
        
        Conditions:
        
        - Base bundle name: `foo.bar.Messages`
        - Requested `Locale`: Locale.ITALY
        - Default `Locale`: Locale.FRENCH
        - Available resource bundles:
        `foo/bar/Messages_fr.properties` and
        `foo/bar/Messages.properties`
        
        
        First, `getBundle` tries loading a resource bundle in
        the following sequence.
        
        
        - class `foo.bar.Messages_it_IT`
        - file `foo/bar/Messages_it_IT.properties`
        - class `foo.bar.Messages_it`
        - file `foo/bar/Messages_it.properties`
        - class `foo.bar.Messages`
        - file `foo/bar/Messages.properties`
        
        
        At this point, `getBundle` finds
        `foo/bar/Messages.properties`, which is put on hold
        because it's the base bundle.  `getBundle` calls Control.getFallbackLocale(String, Locale)
        control.getFallbackLocale("foo.bar.Messages", Locale.ITALY) which
        returns `Locale.FRENCH`. Next, `getBundle`
        tries loading a bundle in the following sequence.
        
        
        - class `foo.bar.Messages_fr`
        - file `foo/bar/Messages_fr.properties`
        - class `foo.bar.Messages`
        - file `foo/bar/Messages.properties`
        
        
        `getBundle` finds
        `foo/bar/Messages_fr.properties` and creates a
        `ResourceBundle` instance. Then, `getBundle`
        sets up its parent chain from the list of the candidate locales.  Only
        `foo/bar/Messages.properties` is found in the list and
        `getBundle` creates a `ResourceBundle` instance
        that becomes the parent of the instance for
        `foo/bar/Messages_fr.properties`.

        Arguments
        - baseName: the base name of the resource bundle, a fully qualified
               class name
        - targetLocale: the locale for which a resource bundle is desired
        - loader: the class loader from which to load the resource bundle
        - control: the control which gives information for the resource
               bundle loading process

        Returns
        - a resource bundle for the given base name and locale

        Raises
        - NullPointerException: if `baseName`, `targetLocale`,
                `loader`, or `control` is
                `null`
        - MissingResourceException: if no resource bundle for the specified base name can be found
        - IllegalArgumentException: if the given `control` doesn't perform properly
                (e.g., `control.getCandidateLocales` returns null.)
                Note that validation of `control` is performed as
                needed.
        - UnsupportedOperationException: if this method is called in a named module

        Since
        - 1.6

        Unknown Tags
        - 9
        """
        ...


    @staticmethod
    def clearCache() -> None:
        """
        Removes all resource bundles from the cache that have been loaded
        by the caller's module.

        See
        - ResourceBundle.Control.getTimeToLive(String,Locale)

        Since
        - 1.6

        Unknown Tags
        - 9
        """
        ...


    @staticmethod
    def clearCache(loader: "ClassLoader") -> None:
        """
        Removes all resource bundles from the cache that have been loaded
        by the given class loader.

        Arguments
        - loader: the class loader

        Raises
        - NullPointerException: if `loader` is null

        See
        - ResourceBundle.Control.getTimeToLive(String,Locale)

        Since
        - 1.6
        """
        ...


    def getKeys(self) -> "Enumeration"[str]:
        """
        Returns an enumeration of the keys.

        Returns
        - an `Enumeration` of the keys contained in
                this `ResourceBundle` and its parent bundles.
        """
        ...


    def containsKey(self, key: str) -> bool:
        """
        Determines whether the given `key` is contained in
        this `ResourceBundle` or its parent bundles.

        Arguments
        - key: the resource `key`

        Returns
        - `True` if the given `key` is
               contained in this `ResourceBundle` or its
               parent bundles; `False` otherwise.

        Raises
        - NullPointerException: if `key` is `null`

        Since
        - 1.6
        """
        ...


    def keySet(self) -> set[str]:
        """
        Returns a `Set` of all keys contained in this
        `ResourceBundle` and its parent bundles.

        Returns
        - a `Set` of all keys contained in this
                `ResourceBundle` and its parent bundles.

        Since
        - 1.6
        """
        ...


    class Control:
        """
        `ResourceBundle.Control` defines a set of callback methods
        that are invoked by the ResourceBundle.getBundle(String,
        Locale, ClassLoader, Control) ResourceBundle.getBundle factory
        methods during the bundle loading process. In other words, a
        `ResourceBundle.Control` collaborates with the factory
        methods for loading resource bundles. The default implementation of
        the callback methods provides the information necessary for the
        factory methods to perform the <a
        href="./ResourceBundle.html#default_behavior">default behavior</a>.
        
         ResourceBundle.Control is designed for an application deployed
        in an unnamed module, for example to support resource bundles in
        non-standard formats or package localized resources in a non-traditional
        convention. ResourceBundleProvider is the replacement for
        `ResourceBundle.Control` when migrating to modules.
        `UnsupportedOperationException` will be thrown when a factory
        method that takes the `ResourceBundle.Control` parameter is called.
        
        In addition to the callback methods, the .toBundleName(String, Locale) toBundleName and .toResourceName(String, String) toResourceName methods are defined
        primarily for convenience in implementing the callback
        methods. However, the `toBundleName` method could be
        overridden to provide different conventions in the organization and
        packaging of localized resources.  The `toResourceName`
        method is `final` to avoid use of wrong resource and class
        name separators.
        
        Two factory methods, .getControl(List) and .getNoFallbackControl(List), provide
        `ResourceBundle.Control` instances that implement common
        variations of the default bundle loading process.
        
        The formats returned by the Control.getFormats(String)
        getFormats method and candidate locales returned by the ResourceBundle.Control.getCandidateLocales(String, Locale)
        getCandidateLocales method must be consistent in all
        `ResourceBundle.getBundle` invocations for the same base
        bundle. Otherwise, the `ResourceBundle.getBundle` methods
        may return unintended bundles. For example, if only
        `"java.class"` is returned by the `getFormats`
        method for the first call to `ResourceBundle.getBundle`
        and only `"java.properties"` for the second call, then the
        second call will return the class-based one that has been cached
        during the first call.
        
        A `ResourceBundle.Control` instance must be thread-safe
        if it's simultaneously used by multiple threads.
        `ResourceBundle.getBundle` does not synchronize to call
        the `ResourceBundle.Control` methods. The default
        implementations of the methods are thread-safe.
        
        Applications can specify `ResourceBundle.Control`
        instances returned by the `getControl` factory methods or
        created from a subclass of `ResourceBundle.Control` to
        customize the bundle loading process. The following are examples of
        changing the default bundle loading process.
        
        **Example 1**
        
        The following code lets `ResourceBundle.getBundle` look
        up only properties-based resources.
        
        ```
        import java.util.*;
        import static java.util.ResourceBundle.Control.*;
        ...
        ResourceBundle bundle =
          ResourceBundle.getBundle("MyResources", new Locale("fr", "CH"),
                                   ResourceBundle.Control.getControl(FORMAT_PROPERTIES));
        ```
        
        Given the resource bundles in the <a
        href="./ResourceBundle.html#default_behavior_example">example</a> in
        the `ResourceBundle.getBundle` description, this
        `ResourceBundle.getBundle` call loads
        `MyResources_fr_CH.properties` whose parent is
        `MyResources_fr.properties` whose parent is
        `MyResources.properties`. (`MyResources_fr_CH.properties`
        is not hidden, but `MyResources_fr_CH.class` is.)
        
        **Example 2**
        
        The following is an example of loading XML-based bundles
        using Properties.loadFromXML(java.io.InputStream)
        Properties.loadFromXML.
        
        ```
        ResourceBundle rb = ResourceBundle.getBundle("Messages",
            new ResourceBundle.Control() {
                public List&lt;String&gt; getFormats(String baseName) {
                    if (baseName == null)
                        throw new NullPointerException();
                    return Arrays.asList("xml");
                }
                public ResourceBundle newBundle(String baseName,
                                                Locale locale,
                                                String format,
                                                ClassLoader loader,
                                                boolean reload)
                                 throws IllegalAccessException,
                                        InstantiationException,
                                        IOException {
                    if (baseName == null || locale == null
                          || format == null || loader == null)
                        throw new NullPointerException();
                    ResourceBundle bundle = null;
                    if (format.equals("xml")) {
                        String bundleName = toBundleName(baseName, locale);
                        String resourceName = toResourceName(bundleName, format);
                        InputStream stream = null;
                        if (reload) {
                            URL url = loader.getResource(resourceName);
                            if (url != null) {
                                URLConnection connection = url.openConnection();
                                if (connection != null) {
                                    // Disable caches to get fresh data for
                                    // reloading.
                                    connection.setUseCaches(False);
                                    stream = connection.getInputStream();
                                }
                            }
                        } else {
                            stream = loader.getResourceAsStream(resourceName);
                        }
                        if (stream != null) {
                            BufferedInputStream bis = new BufferedInputStream(stream);
                            bundle = new XMLResourceBundle(bis);
                            bis.close();
                        }
                    }
                    return bundle;
                }
            });
        
        ...
        
        private static class XMLResourceBundle extends ResourceBundle {
            private Properties props;
            XMLResourceBundle(InputStream stream) throws IOException {
                props = new Properties();
                props.loadFromXML(stream);
            }
            protected Object handleGetObject(String key) {
                return props.getProperty(key);
            }
            public Enumeration&lt;String&gt; getKeys() {
                ...
            }
        }
        ```

        See
        - java.util.spi.ResourceBundleProvider

        Since
        - 1.6

        Unknown Tags
        - `ResourceBundle.Control` is not supported
        in named modules. If the `ResourceBundle.getBundle` method with
        a `ResourceBundle.Control` is called in a named module, the method
        will throw an UnsupportedOperationException. Any service providers
        of ResourceBundleControlProvider are ignored in named modules.
        - 9
        """

        FORMAT_DEFAULT = List.of("java.class", "java.properties")
        """
        The default format `List`, which contains the strings
        `"java.class"` and `"java.properties"`, in
        this order. This `List` is unmodifiable.

        See
        - .getFormats(String)
        """
        FORMAT_CLASS = List.of("java.class")
        """
        The class-only format `List` containing
        `"java.class"`. This `List` is unmodifiable.

        See
        - .getFormats(String)
        """
        FORMAT_PROPERTIES = List.of("java.properties")
        """
        The properties-only format `List` containing
        `"java.properties"`. This `List` is unmodifiable.

        See
        - .getFormats(String)
        """
        TTL_DONT_CACHE = -1
        """
        The time-to-live constant for not caching loaded resource bundle
        instances.

        See
        - .getTimeToLive(String, Locale)
        """
        TTL_NO_EXPIRATION_CONTROL = -2
        """
        The time-to-live constant for disabling the expiration control
        for loaded resource bundle instances in the cache.

        See
        - .getTimeToLive(String, Locale)
        """


        @staticmethod
        def getControl(formats: list[str]) -> "Control":
            """
            Returns a `ResourceBundle.Control` in which the .getFormats(String) getFormats method returns the specified
            `formats`. The `formats` must be equal to
            one of Control.FORMAT_PROPERTIES, Control.FORMAT_CLASS or Control.FORMAT_DEFAULT. `ResourceBundle.Control`
            instances returned by this method are singletons and thread-safe.
            
            Specifying Control.FORMAT_DEFAULT is equivalent to
            instantiating the `ResourceBundle.Control` class,
            except that this method returns a singleton.

            Arguments
            - formats: the formats to be returned by the
                   `ResourceBundle.Control.getFormats` method

            Returns
            - a `ResourceBundle.Control` supporting the
                   specified `formats`

            Raises
            - NullPointerException: if `formats` is `null`
            - IllegalArgumentException: if `formats` is unknown
            """
            ...


        @staticmethod
        def getNoFallbackControl(formats: list[str]) -> "Control":
            """
            Returns a `ResourceBundle.Control` in which the .getFormats(String) getFormats method returns the specified
            `formats` and the Control.getFallbackLocale(String, Locale) getFallbackLocale
            method returns `null`. The `formats` must
            be equal to one of Control.FORMAT_PROPERTIES, Control.FORMAT_CLASS or Control.FORMAT_DEFAULT.
            `ResourceBundle.Control` instances returned by this
            method are singletons and thread-safe.

            Arguments
            - formats: the formats to be returned by the
                   `ResourceBundle.Control.getFormats` method

            Returns
            - a `ResourceBundle.Control` supporting the
                   specified `formats` with no fallback
                   `Locale` support

            Raises
            - NullPointerException: if `formats` is `null`
            - IllegalArgumentException: if `formats` is unknown
            """
            ...


        def getFormats(self, baseName: str) -> list[str]:
            """
            Returns a `List` of `String`s containing
            formats to be used to load resource bundles for the given
            `baseName`. The `ResourceBundle.getBundle`
            factory method tries to load resource bundles with formats in the
            order specified by the list. The list returned by this method
            must have at least one `String`. The predefined
            formats are `"java.class"` for class-based resource
            bundles and `"java.properties"` for PropertyResourceBundle properties-based ones. Strings starting
            with `"java."` are reserved for future extensions and
            must not be used by application-defined formats.
            
            It is not a requirement to return an immutable (unmodifiable)
            `List`.  However, the returned `List` must
            not be mutated after it has been returned by
            `getFormats`.
            
            The default implementation returns .FORMAT_DEFAULT so
            that the `ResourceBundle.getBundle` factory method
            looks up first class-based resource bundles, then
            properties-based ones.

            Arguments
            - baseName: the base name of the resource bundle, a fully qualified class
                   name

            Returns
            - a `List` of `String`s containing
                   formats for loading resource bundles.

            Raises
            - NullPointerException: if `baseName` is null

            See
            - .FORMAT_PROPERTIES
            """
            ...


        def getCandidateLocales(self, baseName: str, locale: "Locale") -> list["Locale"]:
            """
            Returns a `List` of `Locale`s as candidate
            locales for `baseName` and `locale`. This
            method is called by the `ResourceBundle.getBundle`
            factory method each time the factory method tries finding a
            resource bundle for a target `Locale`.
            
            The sequence of the candidate locales also corresponds to the
            runtime resource lookup path (also known as the <I>parent
            chain</I>), if the corresponding resource bundles for the
            candidate locales exist and their parents are not defined by
            loaded resource bundles themselves.  The last element of the list
            must be a Locale.ROOT root locale if it is desired to
            have the base bundle as the terminal of the parent chain.
            
            If the given locale is equal to `Locale.ROOT` (the
            root locale), a `List` containing only the root
            `Locale` must be returned. In this case, the
            `ResourceBundle.getBundle` factory method loads only
            the base bundle as the resulting resource bundle.
            
            It is not a requirement to return an immutable (unmodifiable)
            `List`. However, the returned `List` must not
            be mutated after it has been returned by
            `getCandidateLocales`.
            
            The default implementation returns a `List` containing
            `Locale`s using the rules described below.  In the
            description below, *L*, *S*, *C* and *V*
            respectively represent non-empty language, script, country, and
            variant.  For example, [*L*, *C*] represents a
            `Locale` that has non-empty values only for language and
            country.  The form *L*("xx") represents the (non-empty)
            language value is "xx".  For all cases, `Locale`s whose
            final component values are empty strings are omitted.
            
            <ol>- For an input `Locale` with an empty script value,
            append candidate `Locale`s by omitting the final component
            one by one as below:
            
            
            -  [*L*, *C*, *V*] 
            -  [*L*, *C*] 
            -  [*L*] 
            -  `Locale.ROOT` 
            
            
            - For an input `Locale` with a non-empty script value,
            append candidate `Locale`s by omitting the final component
            up to language, then append candidates generated from the
            `Locale` with country and variant restored:
            
            
            -  [*L*, *S*, *C*, *V*]
            -  [*L*, *S*, *C*]
            -  [*L*, *S*]
            -  [*L*, *C*, *V*]
            -  [*L*, *C*]
            -  [*L*]
            -  `Locale.ROOT`
            
            
            - For an input `Locale` with a variant value consisting
            of multiple subtags separated by underscore, generate candidate
            `Locale`s by omitting the variant subtags one by one, then
            insert them after every occurrence of `Locale`s with the
            full variant value in the original list.  For example, if
            the variant consists of two subtags *V1* and *V2*:
            
            
            -  [*L*, *S*, *C*, *V1*, *V2*]
            -  [*L*, *S*, *C*, *V1*]
            -  [*L*, *S*, *C*]
            -  [*L*, *S*]
            -  [*L*, *C*, *V1*, *V2*]
            -  [*L*, *C*, *V1*]
            -  [*L*, *C*]
            -  [*L*]
            -  `Locale.ROOT`
            
            
            - Special cases for Chinese.  When an input `Locale` has the
            language "zh" (Chinese) and an empty script value, either "Hans" (Simplified) or
            "Hant" (Traditional) might be supplied, depending on the country.
            When the country is "CN" (China) or "SG" (Singapore), "Hans" is supplied.
            When the country is "HK" (Hong Kong SAR China), "MO" (Macau SAR China),
            or "TW" (Taiwan), "Hant" is supplied.  For all other countries or when the country
            is empty, no script is supplied.  For example, for `Locale("zh", "CN")
            `, the candidate list will be:
            
            -  [*L*("zh"), *S*("Hans"), *C*("CN")]
            -  [*L*("zh"), *S*("Hans")]
            -  [*L*("zh"), *C*("CN")]
            -  [*L*("zh")]
            -  `Locale.ROOT`
            
            
            For `Locale("zh", "TW")`, the candidate list will be:
            
            -  [*L*("zh"), *S*("Hant"), *C*("TW")]
            -  [*L*("zh"), *S*("Hant")]
            -  [*L*("zh"), *C*("TW")]
            -  [*L*("zh")]
            -  `Locale.ROOT`
            
            
            - Special cases for Norwegian.  Both `Locale("no", "NO",
            "NY")` and `Locale("nn", "NO")` represent Norwegian
            Nynorsk.  When a locale's language is "nn", the standard candidate
            list is generated up to [*L*("nn")], and then the following
            candidates are added:
            
            -  [*L*("no"), *C*("NO"), *V*("NY")]
            -  [*L*("no"), *C*("NO")]
            -  [*L*("no")]
            -  `Locale.ROOT`
            
            
            If the locale is exactly `Locale("no", "NO", "NY")`, it is first
            converted to `Locale("nn", "NO")` and then the above procedure is
            followed.
            
            Also, Java treats the language "no" as a synonym of Norwegian
            Bokm&#xE5;l "nb".  Except for the single case `Locale("no",
            "NO", "NY")` (handled above), when an input `Locale`
            has language "no" or "nb", candidate `Locale`s with
            language code "no" and "nb" are interleaved, first using the
            requested language, then using its synonym. For example,
            `Locale("nb", "NO", "POSIX")` generates the following
            candidate list:
            
            
            -  [*L*("nb"), *C*("NO"), *V*("POSIX")]
            -  [*L*("no"), *C*("NO"), *V*("POSIX")]
            -  [*L*("nb"), *C*("NO")]
            -  [*L*("no"), *C*("NO")]
            -  [*L*("nb")]
            -  [*L*("no")]
            -  `Locale.ROOT`
            
            
            `Locale("no", "NO", "POSIX")` would generate the same list
            except that locales with "no" would appear before the corresponding
            locales with "nb".
            </ol>
            
            The default implementation uses an ArrayList that
            overriding implementations may modify before returning it to the
            caller. However, a subclass must not modify it after it has
            been returned by `getCandidateLocales`.
            
            For example, if the given `baseName` is "Messages"
            and the given `locale` is
            `Locale("ja",&nbsp;"",&nbsp;"XX")`, then a
            `List` of `Locale`s:
            ```
                Locale("ja", "", "XX")
                Locale("ja")
                Locale.ROOT
            ```
            is returned. And if the resource bundles for the "ja" and
            "" `Locale`s are found, then the runtime resource
            lookup path (parent chain) is:
            ````Messages_ja -> Messages````

            Arguments
            - baseName: the base name of the resource bundle, a fully
                   qualified class name
            - locale: the locale for which a resource bundle is desired

            Returns
            - a `List` of candidate
                   `Locale`s for the given `locale`

            Raises
            - NullPointerException: if `baseName` or `locale` is
                   `null`
            """
            ...


        def getFallbackLocale(self, baseName: str, locale: "Locale") -> "Locale":
            """
            Returns a `Locale` to be used as a fallback locale for
            further resource bundle searches by the
            `ResourceBundle.getBundle` factory method. This method
            is called from the factory method every time when no resulting
            resource bundle has been found for `baseName` and
            `locale`, where locale is either the parameter for
            `ResourceBundle.getBundle` or the previous fallback
            locale returned by this method.
            
            The method returns `null` if no further fallback
            search is desired.
            
            The default implementation returns the Locale.getDefault() default {@code Locale} if the given
            `locale` isn't the default one.  Otherwise,
            `null` is returned.

            Arguments
            - baseName: the base name of the resource bundle, a fully
                   qualified class name for which
                   `ResourceBundle.getBundle` has been
                   unable to find any resource bundles (except for the
                   base bundle)
            - locale: the `Locale` for which
                   `ResourceBundle.getBundle` has been
                   unable to find any resource bundles (except for the
                   base bundle)

            Returns
            - a `Locale` for the fallback search,
                   or `null` if no further fallback search
                   is desired.

            Raises
            - NullPointerException: if `baseName` or `locale`
                   is `null`
            """
            ...


        def newBundle(self, baseName: str, locale: "Locale", format: str, loader: "ClassLoader", reload: bool) -> "ResourceBundle":
            """
            Instantiates a resource bundle for the given bundle name of the
            given format and locale, using the given class loader if
            necessary. This method returns `null` if there is no
            resource bundle available for the given parameters. If a resource
            bundle can't be instantiated due to an unexpected error, the
            error must be reported by throwing an `Error` or
            `Exception` rather than simply returning
            `null`.
            
            If the `reload` flag is `True`, it
            indicates that this method is being called because the previously
            loaded resource bundle has expired.

            Arguments
            - baseName: the base bundle name of the resource bundle, a fully
                   qualified class name
            - locale: the locale for which the resource bundle should be
                   instantiated
            - format: the resource bundle format to be loaded
            - loader: the `ClassLoader` to use to load the bundle
            - reload: the flag to indicate bundle reloading; `True`
                   if reloading an expired resource bundle,
                   `False` otherwise

            Returns
            - the resource bundle instance,
                   or `null` if none could be found.

            Raises
            - NullPointerException: if `bundleName`, `locale`,
                   `format`, or `loader` is
                   `null`, or if `null` is returned by
                   .toBundleName(String, Locale) toBundleName
            - IllegalArgumentException: if `format` is unknown, or if the resource
                   found for the given parameters contains malformed data.
            - ClassCastException: if the loaded class cannot be cast to `ResourceBundle`
            - IllegalAccessException: if the class or its nullary constructor is not
                   accessible.
            - InstantiationException: if the instantiation of a class fails for some other
                   reason.
            - ExceptionInInitializerError: if the initialization provoked by this method fails.
            - SecurityException: If a security manager is present and creation of new
                   instances is denied. See Class.newInstance()
                   for details.
            - IOException: if an error occurred when reading resources using
                   any I/O operations

            See
            - java.util.spi.ResourceBundleProvider.getBundle(String, Locale)

            Unknown Tags
            - Resource bundles in named modules are subject to the encapsulation
            rules specified by Module.getResourceAsStream Module.getResourceAsStream.
            A resource bundle in a named module visible to the given class loader
            is accessible when the package of the resource file corresponding
            to the resource bundle is open unconditionally.
            
            The default implementation instantiates a
            `ResourceBundle` as follows.
            
            
            
            - The bundle name is obtained by calling .toBundleName(String, Locale) toBundleName(baseName,
            locale).
            
            - If `format` is `"java.class"`, the
            Class specified by the bundle name is loaded with the
            given class loader. If the `Class` is found and accessible
            then the `ResourceBundle` is instantiated.  The
            resource bundle is accessible if the package of the bundle class file
            is open unconditionally; otherwise, `IllegalAccessException`
            will be thrown.
            Note that the `reload` flag is ignored for loading
            class-based resource bundles in this default implementation.
            
            
            - If `format` is `"java.properties"`,
            .toResourceName(String, String) toResourceName(bundlename,
            "properties") is called to get the resource name.
            If `reload` is `True`, ClassLoader.getResource(String) load.getResource is called
            to get a URL for creating a URLConnection. This `URLConnection` is used to
            URLConnection.setUseCaches(boolean) disable the
            caches of the underlying resource loading layers,
            and to URLConnection.getInputStream() get an
            {@code InputStream}.
            Otherwise, ClassLoader.getResourceAsStream(String)
            loader.getResourceAsStream is called to get an InputStream. Then, a PropertyResourceBundle is constructed with the
            `InputStream`.
            
            - If `format` is neither `"java.class"`
            nor `"java.properties"`, an
            `IllegalArgumentException` is thrown.
            
            - If the `locale`'s language is one of the
            <a href="./Locale.html#legacy_language_codes">Legacy language
            codes</a>, either old or new, then repeat the loading process
            if needed, with the bundle name with the other language.
            For example, "iw" for "he" and vice versa.
            
            
            - 9
            """
            ...


        def getTimeToLive(self, baseName: str, locale: "Locale") -> int:
            """
            Returns the time-to-live (TTL) value for resource bundles that
            are loaded under this
            `ResourceBundle.Control`. Positive time-to-live values
            specify the number of milliseconds a bundle can remain in the
            cache without being validated against the source data from which
            it was constructed. The value 0 indicates that a bundle must be
            validated each time it is retrieved from the cache. .TTL_DONT_CACHE specifies that loaded resource bundles are not
            put in the cache. .TTL_NO_EXPIRATION_CONTROL specifies
            that loaded resource bundles are put in the cache with no
            expiration control.
            
            The expiration affects only the bundle loading process by the
            `ResourceBundle.getBundle` factory method.  That is,
            if the factory method finds a resource bundle in the cache that
            has expired, the factory method calls the .needsReload(String, Locale, String, ClassLoader, ResourceBundle,
            long) needsReload method to determine whether the resource
            bundle needs to be reloaded. If `needsReload` returns
            `True`, the cached resource bundle instance is removed
            from the cache. Otherwise, the instance stays in the cache,
            updated with the new TTL value returned by this method.
            
            All cached resource bundles are subject to removal from the
            cache due to memory constraints of the runtime environment.
            Returning a large positive value doesn't mean to lock loaded
            resource bundles in the cache.
            
            The default implementation returns .TTL_NO_EXPIRATION_CONTROL.

            Arguments
            - baseName: the base name of the resource bundle for which the
                   expiration value is specified.
            - locale: the locale of the resource bundle for which the
                   expiration value is specified.

            Returns
            - the time (0 or a positive millisecond offset from the
                   cached time) to get loaded bundles expired in the cache,
                   .TTL_NO_EXPIRATION_CONTROL to disable the
                   expiration control, or .TTL_DONT_CACHE to disable
                   caching.

            Raises
            - NullPointerException: if `baseName` or `locale` is
                   `null`
            """
            ...


        def needsReload(self, baseName: str, locale: "Locale", format: str, loader: "ClassLoader", bundle: "ResourceBundle", loadTime: int) -> bool:
            """
            Determines if the expired `bundle` in the cache needs
            to be reloaded based on the loading time given by
            `loadTime` or some other criteria. The method returns
            `True` if reloading is required; `False`
            otherwise. `loadTime` is a millisecond offset since
            the <a href="Calendar.html#Epoch"> `Calendar`
            Epoch</a>.
            
            
            The calling `ResourceBundle.getBundle` factory method
            calls this method on the `ResourceBundle.Control`
            instance used for its current invocation, not on the instance
            used in the invocation that originally loaded the resource
            bundle.
            
            The default implementation compares `loadTime` and
            the last modified time of the source data of the resource
            bundle. If it's determined that the source data has been modified
            since `loadTime`, `True` is
            returned. Otherwise, `False` is returned. This
            implementation assumes that the given `format` is the
            same string as its file suffix if it's not one of the default
            formats, `"java.class"` or
            `"java.properties"`.

            Arguments
            - baseName: the base bundle name of the resource bundle, a
                   fully qualified class name
            - locale: the locale for which the resource bundle
                   should be instantiated
            - format: the resource bundle format to be loaded
            - loader: the `ClassLoader` to use to load the bundle
            - bundle: the resource bundle instance that has been expired
                   in the cache
            - loadTime: the time when `bundle` was loaded and put
                   in the cache

            Returns
            - `True` if the expired bundle needs to be
                   reloaded; `False` otherwise.

            Raises
            - NullPointerException: if `baseName`, `locale`,
                   `format`, `loader`, or
                   `bundle` is `null`
            """
            ...


        def toBundleName(self, baseName: str, locale: "Locale") -> str:
            """
            Converts the given `baseName` and `locale`
            to the bundle name. This method is called from the default
            implementation of the .newBundle(String, Locale, String,
            ClassLoader, boolean) newBundle and .needsReload(String,
            Locale, String, ClassLoader, ResourceBundle, long) needsReload
            methods.
            
            This implementation returns the following value:
            ```
                baseName + "_" + language + "_" + script + "_" + country + "_" + variant
            ```
            where `language`, `script`, `country`,
            and `variant` are the language, script, country, and variant
            values of `locale`, respectively. Final component values that
            are empty Strings are omitted along with the preceding '_'.  When the
            script is empty, the script value is omitted along with the preceding '_'.
            If all of the values are empty strings, then `baseName`
            is returned.
            
            For example, if `baseName` is
            `"baseName"` and `locale` is
            `Locale("ja",&nbsp;"",&nbsp;"XX")`, then
            `"baseName_ja_&thinsp;_XX"` is returned. If the given
            locale is `Locale("en")`, then
            `"baseName_en"` is returned.
            
            Overriding this method allows applications to use different
            conventions in the organization and packaging of localized
            resources.

            Arguments
            - baseName: the base name of the resource bundle, a fully
                   qualified class name
            - locale: the locale for which a resource bundle should be
                   loaded

            Returns
            - the bundle name for the resource bundle

            Raises
            - NullPointerException: if `baseName` or `locale`
                   is `null`

            See
            - java.util.spi.AbstractResourceBundleProvider.toBundleName(String, Locale)
            """
            ...


        def toResourceName(self, bundleName: str, suffix: str) -> str:
            """
            Converts the given `bundleName` to the form required
            by the ClassLoader.getResource ClassLoader.getResource
            method by replacing all occurrences of `'.'` in
            `bundleName` with `'/'` and appending a
            `'.'` and the given file `suffix`. For
            example, if `bundleName` is
            `"foo.bar.MyResources_ja_JP"` and `suffix`
            is `"properties"`, then
            `"foo/bar/MyResources_ja_JP.properties"` is returned.

            Arguments
            - bundleName: the bundle name
            - suffix: the file type suffix

            Returns
            - the converted resource name

            Raises
            - NullPointerException: if `bundleName` or `suffix`
                    is `null`
            """
            ...



"""
Python module generated from Java source file org.bukkit.entity.Guardian

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Guardian(Monster):

    def setLaser(self, activated: bool) -> bool:
        """
        Sets whether the guardian laser should show or not.
        
        A target must be present. If no target is present the laser will not show
        and the method will return False.

        Arguments
        - activated: whether the laser is active

        Returns
        - True if the laser was activated otherwise False

        See
        - .setTarget(LivingEntity)
        """
        ...


    def hasLaser(self) -> bool:
        """
        Gets whether the guardian laser is active or not.

        Returns
        - True if the laser is active otherwise False
        """
        ...


    def getLaserDuration(self) -> int:
        """
        Get the duration (in ticks) that a laser attack takes.

        Returns
        - the laser duration in ticks
        """
        ...


    def setLaserTicks(self, ticks: int) -> None:
        """
        Set the amount of ticks that have elapsed since this guardian has initiated
        a laser attack. If set to .getLaserDuration() or greater, the guardian
        will inflict damage upon its target and the laser attack will complete.
        
        For this value to have any effect, the guardian must have an active target
        (see .setTarget(LivingEntity)) and be charging a laser attack (where
        .hasLaser() is True). The client may display a different animation of
        the guardian laser than the set ticks.

        Arguments
        - ticks: the ticks to set. Must be at least -10
        """
        ...


    def getLaserTicks(self) -> int:
        """
        Get the amount of ticks that have elapsed since this guardian has initiated
        a laser attack.
        
        This value may or may not be significant depending on whether or not the guardian
        has an active target (.getTarget()) and is charging a laser attack
        (.hasLaser()). This value is not reset after a successful attack nor used
        in the next and will be reset to the minimum value when the guardian initiates a
        new one.

        Returns
        - the laser ticks ranging from -10 to .getLaserDuration()
        """
        ...


    def isElder(self) -> bool:
        """
        Check if the Guardian is an elder Guardian

        Returns
        - True if the Guardian is an Elder Guardian, False if not

        Deprecated
        - should check if instance of ElderGuardian.
        """
        ...


    def setElder(self, shouldBeElder: bool) -> None:
        """
        Arguments
        - shouldBeElder: shouldBeElder

        Deprecated
        - Must spawn a new ElderGuardian.
        """
        ...


    def isMoving(self) -> bool:
        """
        Check whether or not this guardian is moving.
        
        While moving, the guardian's spikes are retracted and will not inflict thorns
        damage upon entities that attack it. Additionally, a moving guardian cannot
        attack another entity. If stationary (i.e. this method returns `False`),
        thorns damage is guaranteed and the guardian may initiate laser attacks.

        Returns
        - True if moving, False if stationary
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.util import Arrays
from java.util import Comparator
from java.util import NavigableMap
from java.util import SortedMap
from java.util import Spliterator
from java.util.function import BiConsumer
from java.util.function import BinaryOperator
from java.util.function import Consumer
from java.util.function import Function
from java.util.stream import Collector
from java.util.stream import Collectors
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedMap(ImmutableMap, NavigableMap):
    """
    A NavigableMap whose contents will never change, with many other important properties
    detailed at ImmutableCollection.
    
    **Warning:** as with any sorted collection, you are strongly advised not to use a Comparator or Comparable type whose comparison behavior is *inconsistent with
    equals*. That is, `a.compareTo(b)` or `comparator.compare(a, b)` should equal zero
    *if and only if* `a.equals(b)`. If this advice is not followed, the resulting map will
    not correctly obey its specification.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/ImmutableCollectionsExplained">immutable collections</a>.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0 (implements `NavigableMap` since 12.0)
    """

    @staticmethod
    def toImmutableSortedMap(comparator: "Comparator"["K"], keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"]) -> "Collector"["T", Any, "ImmutableSortedMap"["K", "V"]]:
        """
        Returns a Collector that accumulates elements into an `ImmutableSortedMap` whose
        keys and values are the result of applying the provided mapping functions to the input
        elements. The generated map is sorted by the specified comparator.
        
        If the mapped keys contain duplicates (according to the specified comparator), an `IllegalArgumentException` is thrown when the collection operation is performed. (This differs
        from the `Collector` returned by Collectors.toMap(Function, Function), which
        throws an `IllegalStateException`.)

        Since
        - 21.0
        """
        ...


    @staticmethod
    def toImmutableSortedMap(comparator: "Comparator"["K"], keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"], mergeFunction: "BinaryOperator"["V"]) -> "Collector"["T", Any, "ImmutableSortedMap"["K", "V"]]:
        """
        Returns a Collector that accumulates elements into an `ImmutableSortedMap` whose
        keys and values are the result of applying the provided mapping functions to the input
        elements.
        
        If the mapped keys contain duplicates (according to the comparator), the values are merged
        using the specified merging function. Entries will appear in the encounter order of the first
        occurrence of the key.

        Since
        - 21.0
        """
        ...


    @staticmethod
    def of() -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns the empty sorted map.
        
        **Performance note:** the instance returned is a singleton.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable map containing a single entry.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if the two keys are equal according to their natural ordering
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering

        Since
        - 31.0
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V", k10: "K", v10: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable sorted map containing the given entries, sorted by the natural ordering of
        their keys.

        Raises
        - IllegalArgumentException: if any two keys are equal according to their natural ordering

        Since
        - 31.0
        """
        ...


    @staticmethod
    def copyOf(map: dict["K", "V"]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable map containing the same entries as `map`, sorted by the natural
        ordering of the keys.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.
        
        This method is not type-safe, as it may be called on a map with keys that are not mutually
        comparable.

        Raises
        - ClassCastException: if the keys in `map` are not mutually comparable
        - NullPointerException: if any key or value in `map` is null
        - IllegalArgumentException: if any two keys are equal according to their natural ordering
        """
        ...


    @staticmethod
    def copyOf(map: dict["K", "V"], comparator: "Comparator"["K"]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable map containing the same entries as `map`, with keys sorted by the
        provided comparator.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if any key or value in `map` is null
        - IllegalArgumentException: if any two keys are equal according to the comparator
        """
        ...


    @staticmethod
    def copyOf(entries: Iterable["Entry"["K", "V"]]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, with keys sorted by their natural
        ordering.
        
        This method is not type-safe, as it may be called on a map with keys that are not mutually
        comparable.

        Raises
        - NullPointerException: if any key or value in `map` is null
        - IllegalArgumentException: if any two keys are equal according to the comparator

        Since
        - 19.0
        """
        ...


    @staticmethod
    def copyOf(entries: Iterable["Entry"["K", "V"]], comparator: "Comparator"["K"]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable map containing the given entries, with keys sorted by the provided
        comparator.

        Raises
        - NullPointerException: if any key or value in `map` is null
        - IllegalArgumentException: if any two keys are equal according to the comparator

        Since
        - 19.0
        """
        ...


    @staticmethod
    def copyOfSorted(map: "SortedMap"["K", "V"]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Returns an immutable map containing the same entries as the provided sorted map, with the same
        ordering.
        
        Despite the method name, this method attempts to avoid actually copying the data when it is
        safe to do so. The exact circumstances under which a copy will or will not be performed are
        undocumented and subject to change.

        Raises
        - NullPointerException: if any key or value in `map` is null
        """
        ...


    @staticmethod
    def naturalOrder() -> "Builder"["K", "V"]:
        """
        Returns a builder that creates immutable sorted maps whose keys are ordered by their natural
        ordering. The sorted maps use Ordering.natural() as the comparator.
        """
        ...


    @staticmethod
    def orderedBy(comparator: "Comparator"["K"]) -> "Builder"["K", "V"]:
        """
        Returns a builder that creates immutable sorted maps with an explicit comparator. If the
        comparator has a more general type than the map's keys, such as creating a `SortedMap<Integer, String>` with a `Comparator<Number>`, use the Builder
        constructor instead.

        Raises
        - NullPointerException: if `comparator` is null
        """
        ...


    @staticmethod
    def reverseOrder() -> "Builder"["K", "V"]:
        """
        Returns a builder that creates immutable sorted maps whose keys are ordered by the reverse of
        their natural ordering.
        """
        ...


    def size(self) -> int:
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def entrySet(self) -> "ImmutableSet"["Entry"["K", "V"]]:
        """
        Returns an immutable set of the mappings in this map, sorted by the key ordering.
        """
        ...


    def keySet(self) -> "ImmutableSortedSet"["K"]:
        """
        Returns an immutable sorted set of the keys in this map.
        """
        ...


    def values(self) -> "ImmutableCollection"["V"]:
        """
        Returns an immutable collection of the values in this map, sorted by the ordering of the
        corresponding keys.
        """
        ...


    def comparator(self) -> "Comparator"["K"]:
        """
        Returns the comparator that orders the keys, which is Ordering.natural() when the
        natural ordering of the keys is used. Note that its behavior is not consistent with TreeMap.comparator(), which returns `null` to indicate natural ordering.
        """
        ...


    def firstKey(self) -> "K":
        ...


    def lastKey(self) -> "K":
        ...


    def headMap(self, toKey: "K") -> "ImmutableSortedMap"["K", "V"]:
        """
        This method returns a `ImmutableSortedMap`, consisting of the entries whose keys are less
        than `toKey`.
        
        The SortedMap.headMap documentation states that a submap of a submap throws an
        IllegalArgumentException if passed a `toKey` greater than an earlier `toKey`. However, this method doesn't throw an exception in that situation, but instead keeps
        the original `toKey`.
        """
        ...


    def headMap(self, toKey: "K", inclusive: bool) -> "ImmutableSortedMap"["K", "V"]:
        """
        This method returns a `ImmutableSortedMap`, consisting of the entries whose keys are less
        than (or equal to, if `inclusive`) `toKey`.
        
        The SortedMap.headMap documentation states that a submap of a submap throws an
        IllegalArgumentException if passed a `toKey` greater than an earlier `toKey`. However, this method doesn't throw an exception in that situation, but instead keeps
        the original `toKey`.

        Since
        - 12.0
        """
        ...


    def subMap(self, fromKey: "K", toKey: "K") -> "ImmutableSortedMap"["K", "V"]:
        """
        This method returns a `ImmutableSortedMap`, consisting of the entries whose keys ranges
        from `fromKey`, inclusive, to `toKey`, exclusive.
        
        The SortedMap.subMap documentation states that a submap of a submap throws an IllegalArgumentException if passed a `fromKey` less than an earlier `fromKey`.
        However, this method doesn't throw an exception in that situation, but instead keeps the
        original `fromKey`. Similarly, this method keeps the original `toKey`, instead of
        throwing an exception, if passed a `toKey` greater than an earlier `toKey`.
        """
        ...


    def subMap(self, fromKey: "K", fromInclusive: bool, toKey: "K", toInclusive: bool) -> "ImmutableSortedMap"["K", "V"]:
        """
        This method returns a `ImmutableSortedMap`, consisting of the entries whose keys ranges
        from `fromKey` to `toKey`, inclusive or exclusive as indicated by the boolean
        flags.
        
        The SortedMap.subMap documentation states that a submap of a submap throws an IllegalArgumentException if passed a `fromKey` less than an earlier `fromKey`.
        However, this method doesn't throw an exception in that situation, but instead keeps the
        original `fromKey`. Similarly, this method keeps the original `toKey`, instead of
        throwing an exception, if passed a `toKey` greater than an earlier `toKey`.

        Since
        - 12.0
        """
        ...


    def tailMap(self, fromKey: "K") -> "ImmutableSortedMap"["K", "V"]:
        """
        This method returns a `ImmutableSortedMap`, consisting of the entries whose keys are
        greater than or equals to `fromKey`.
        
        The SortedMap.tailMap documentation states that a submap of a submap throws an
        IllegalArgumentException if passed a `fromKey` less than an earlier `fromKey`. However, this method doesn't throw an exception in that situation, but instead keeps
        the original `fromKey`.
        """
        ...


    def tailMap(self, fromKey: "K", inclusive: bool) -> "ImmutableSortedMap"["K", "V"]:
        """
        This method returns a `ImmutableSortedMap`, consisting of the entries whose keys are
        greater than (or equal to, if `inclusive`) `fromKey`.
        
        The SortedMap.tailMap documentation states that a submap of a submap throws an
        IllegalArgumentException if passed a `fromKey` less than an earlier `fromKey`. However, this method doesn't throw an exception in that situation, but instead keeps
        the original `fromKey`.

        Since
        - 12.0
        """
        ...


    def lowerEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def lowerKey(self, key: "K") -> "K":
        ...


    def floorEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def floorKey(self, key: "K") -> "K":
        ...


    def ceilingEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def ceilingKey(self, key: "K") -> "K":
        ...


    def higherEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def higherKey(self, key: "K") -> "K":
        ...


    def firstEntry(self) -> "Entry"["K", "V"]:
        ...


    def lastEntry(self) -> "Entry"["K", "V"]:
        ...


    def pollFirstEntry(self) -> "Entry"["K", "V"]:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def pollLastEntry(self) -> "Entry"["K", "V"]:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Unsupported operation.
        """
        ...


    def descendingMap(self) -> "ImmutableSortedMap"["K", "V"]:
        ...


    def navigableKeySet(self) -> "ImmutableSortedSet"["K"]:
        ...


    def descendingKeySet(self) -> "ImmutableSortedSet"["K"]:
        ...


    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Not supported. Use .toImmutableSortedMap, which offers better type-safety, instead.
        This method exists only to hide ImmutableMap.toImmutableMap from consumers of `ImmutableSortedMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMap.toImmutableSortedMap.
        """
        ...


    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"], mergeFunction: "BinaryOperator"["V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Not supported. Use .toImmutableSortedMap, which offers better type-safety, instead.
        This method exists only to hide ImmutableMap.toImmutableMap from consumers of `ImmutableSortedMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMap.toImmutableSortedMap.
        """
        ...


    @staticmethod
    def builder() -> "ImmutableSortedMap.Builder"["K", "V"]:
        """
        Not supported. Use .naturalOrder, which offers better type-safety, instead. This method
        exists only to hide ImmutableMap.builder from consumers of `ImmutableSortedMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableSortedMap.naturalOrder, which offers better type-safety.
        """
        ...


    @staticmethod
    def builderWithExpectedSize(expectedSize: int) -> "ImmutableSortedMap.Builder"["K", "V"]:
        """
        Not supported for ImmutableSortedMap.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Not supported for ImmutableSortedMap.
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain a non-`Comparable`
        key.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this dummy
        version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass a key of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls to will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def of(k1: "K", v1: "V", k2: "K", v2: "V", k3: "K", v3: "V", k4: "K", v4: "V", k5: "K", v5: "V", k6: "K", v6: "V", k7: "K", v7: "V", k8: "K", v8: "V", k9: "K", v9: "V", k10: "K", v10: "V") -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. **You are attempting to create a map that may contain non-`Comparable`
        keys.** Proper calls will resolve to the version in `ImmutableSortedMap`, not this
        dummy version.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - **Pass keys of type `Comparable` to use ImmutableSortedMap.of(Comparable, Object, Comparable, Object, Comparable, Object,
            Comparable, Object, Comparable, Object).**
        """
        ...


    @staticmethod
    def ofEntries(*entries: Tuple["Entry"["K", "V"], ...]) -> "ImmutableSortedMap"["K", "V"]:
        """
        Not supported. Use `ImmutableSortedMap.copyOf(ImmutableMap.ofEntries(...))`.

        Deprecated
        - Use `ImmutableSortedMap.copyOf(ImmutableMap.ofEntries(...))`.
        """
        ...


    class Builder(Builder):
        """
        A builder for creating immutable sorted map instances, especially `public static final`
        maps ("constant maps"). Example:
        
        ````static final ImmutableSortedMap<Integer, String> INT_TO_WORD =
            new ImmutableSortedMap.Builder<Integer, String>(Ordering.natural())
                .put(1, "one")
                .put(2, "two")
                .put(3, "three")
                .buildOrThrow();````
        
        For *small* immutable sorted maps, the `ImmutableSortedMap.of()` methods are even
        more convenient.
        
        Builder instances can be reused - it is safe to call .buildOrThrow multiple times to
        build multiple maps in series. Each map is a superset of the maps created before it.

        Since
        - 2.0
        """

        def __init__(self, comparator: "Comparator"["K"]):
            """
            Creates a new builder. The returned builder is equivalent to the builder generated by ImmutableSortedMap.orderedBy.
            """
            ...


        def put(self, key: "K", value: "V") -> "Builder"["K", "V"]:
            """
            Associates `key` with `value` in the built map. Duplicate keys, according to the
            comparator (which might be the keys' natural order), are not allowed, and will cause .build to fail.
            """
            ...


        def put(self, entry: "Entry"["K", "V"]) -> "Builder"["K", "V"]:
            """
            Adds the given `entry` to the map, making it immutable if necessary. Duplicate keys,
            according to the comparator (which might be the keys' natural order), are not allowed, and
            will cause .build to fail.

            Since
            - 11.0
            """
            ...


        def putAll(self, map: dict["K", "V"]) -> "Builder"["K", "V"]:
            """
            Associates all of the given map's keys and values in the built map. Duplicate keys, according
            to the comparator (which might be the keys' natural order), are not allowed, and will cause
            .build to fail.

            Raises
            - NullPointerException: if any key or value in `map` is null
            """
            ...


        def putAll(self, entries: Iterable["Entry"["K", "V"]]) -> "Builder"["K", "V"]:
            """
            Adds all the given entries to the built map. Duplicate keys, according to the comparator
            (which might be the keys' natural order), are not allowed, and will cause .build to
            fail.

            Raises
            - NullPointerException: if any key, value, or entry is null

            Since
            - 19.0
            """
            ...


        def orderEntriesByValue(self, valueComparator: "Comparator"["V"]) -> "Builder"["K", "V"]:
            """
            Throws an `UnsupportedOperationException`.

            Since
            - 19.0

            Deprecated
            - Unsupported by ImmutableSortedMap.Builder.
            """
            ...


        def build(self) -> "ImmutableSortedMap"["K", "V"]:
            """
            Returns a newly-created immutable sorted map.
            
            Prefer the equivalent method .buildOrThrow() to make it explicit that the method
            will throw an exception if there are duplicate keys. The `build()` method will soon be
            deprecated.

            Raises
            - IllegalArgumentException: if any two keys are equal according to the comparator (which
                might be the keys' natural order)
            """
            ...


        def buildOrThrow(self) -> "ImmutableSortedMap"["K", "V"]:
            """
            Returns a newly-created immutable sorted map, or throws an exception if any two keys are
            equal.

            Raises
            - IllegalArgumentException: if any two keys are equal according to the comparator (which
                might be the keys' natural order)

            Since
            - 31.0
            """
            ...


        def buildKeepingLast(self) -> "ImmutableSortedMap"["K", "V"]:
            """
            Throws UnsupportedOperationException. A future version may support this operation. Then the
            value for any given key will be the one that was last supplied in a `put` operation for
            that key.

            Raises
            - UnsupportedOperationException: always

            Since
            - 31.1

            Deprecated
            - This method is not currently implemented, and may never be.
            """
            ...



"""
Python module generated from Java source file net.md_5.bungee.chat.ComponentSerializer

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import GsonBuilder
from com.google.gson import JsonArray
from com.google.gson import JsonDeserializationContext
from com.google.gson import JsonDeserializer
from com.google.gson import JsonElement
from com.google.gson import JsonObject
from com.google.gson import JsonParseException
from com.google.gson import JsonParser
from com.google.gson import JsonPrimitive
from java.lang.reflect import Type
from net.md_5.bungee.api.chat import BaseComponent
from net.md_5.bungee.api.chat import ComponentStyle
from net.md_5.bungee.api.chat import ItemTag
from net.md_5.bungee.api.chat import KeybindComponent
from net.md_5.bungee.api.chat import ScoreComponent
from net.md_5.bungee.api.chat import SelectorComponent
from net.md_5.bungee.api.chat import TextComponent
from net.md_5.bungee.api.chat import TranslatableComponent
from net.md_5.bungee.api.chat.hover.content import Entity
from net.md_5.bungee.api.chat.hover.content import EntitySerializer
from net.md_5.bungee.api.chat.hover.content import Item
from net.md_5.bungee.api.chat.hover.content import ItemSerializer
from net.md_5.bungee.api.chat.hover.content import Text
from net.md_5.bungee.api.chat.hover.content import TextSerializer
from net.md_5.bungee.chat import *
from typing import Any, Callable, Iterable, Tuple


class ComponentSerializer(JsonDeserializer):

    serializedComponents = ThreadLocal<Set<BaseComponent>>()


    @staticmethod
    def parse(json: str) -> list["BaseComponent"]:
        """
        Parse a JSON-compliant String as an array of base components. The input
        can be one of either an array of components, or a single component
        object. If the input is an array, each component will be parsed
        individually and returned in the order that they were parsed. If the
        input is a single component object, a single-valued array with the
        component will be returned.
        
        <strong>NOTE:</strong> .deserialize(String) is preferred as it
        will parse only one component as opposed to an array of components which
        is non- standard behavior. This method is still appropriate for parsing
        multiple components at once, although such use case is rarely (if at all)
        exhibited in vanilla Minecraft.

        Arguments
        - json: the component json to parse

        Returns
        - an array of all parsed components
        """
        ...


    @staticmethod
    def deserialize(json: str) -> "BaseComponent":
        """
        Deserialize a JSON-compliant String as a single component.

        Arguments
        - json: the component json to parse

        Returns
        - the deserialized component

        Raises
        - IllegalArgumentException: if anything other than a valid JSON
        component string is passed as input
        """
        ...


    @staticmethod
    def deserialize(jsonElement: "JsonElement") -> "BaseComponent":
        """
        Deserialize a JSON element as a single component.

        Arguments
        - jsonElement: the component json to parse

        Returns
        - the deserialized component

        Raises
        - IllegalArgumentException: if anything other than a valid JSON
        component is passed as input
        """
        ...


    @staticmethod
    def deserializeStyle(json: str) -> "ComponentStyle":
        """
        Deserialize a JSON-compliant String as a component style.

        Arguments
        - json: the component style json to parse

        Returns
        - the deserialized component style

        Raises
        - IllegalArgumentException: if anything other than a valid JSON
        component style string is passed as input
        """
        ...


    @staticmethod
    def deserializeStyle(jsonElement: "JsonElement") -> "ComponentStyle":
        """
        Deserialize a JSON element as a component style.

        Arguments
        - jsonElement: the component style json to parse

        Returns
        - the deserialized component style

        Raises
        - IllegalArgumentException: if anything other than a valid JSON
        component style is passed as input
        """
        ...


    @staticmethod
    def toJson(component: "BaseComponent") -> "JsonElement":
        ...


    @staticmethod
    def toJson(style: "ComponentStyle") -> "JsonElement":
        ...


    @staticmethod
    def toString(object: "Object") -> str:
        ...


    @staticmethod
    def toString(component: "BaseComponent") -> str:
        ...


    @staticmethod
    def toString(*components: Tuple["BaseComponent", ...]) -> str:
        ...


    @staticmethod
    def toString(style: "ComponentStyle") -> str:
        ...


    def deserialize(self, json: "JsonElement", typeOfT: "Type", context: "JsonDeserializationContext") -> "BaseComponent":
        ...



from .PotionType import PotionType
from .PotionEffectTypeWrapper import PotionEffectTypeWrapper
from .PotionEffect import PotionEffect
from .PotionEffectTypeCategory import PotionEffectTypeCategory
from .PotionBrewer import PotionBrewer
from .PotionData import PotionData
from .PotionEffectType import PotionEffectType


"""
Python module generated from Java source file org.bukkit.event.entity.EntityAirChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityAirChangeEvent(EntityEvent, Cancellable):
    """
    Called when the amount of air an entity has remaining changes.
    """

    def __init__(self, what: "Entity", amount: int):
        ...


    def getAmount(self) -> int:
        """
        Gets the amount of air the entity has left (measured in ticks).

        Returns
        - amount of air remaining
        """
        ...


    def setAmount(self, amount: int) -> None:
        """
        Sets the amount of air remaining for the entity (measured in ticks.

        Arguments
        - amount: amount of air remaining
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingImmutableMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from typing import Any, Callable, Iterable, Tuple


class ForwardingImmutableMap:
    """
    Unused stub class, unreferenced under Java and manually emulated under GWT.

    Author(s)
    - Chris Povirk
    """





"""
Python module generated from Java source file java.util.stream.BaseStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.nio.charset import Charset
from java.nio.file import Files
from java.nio.file import Path
from java.util import Iterator
from java.util import Spliterator
from java.util.concurrent import ConcurrentHashMap
from java.util.function import IntConsumer
from java.util.function import Predicate
from java.util.stream import *
from typing import Any, Callable, Iterable, Tuple


class BaseStream(AutoCloseable):
    """
    Base interface for streams, which are sequences of elements supporting
    sequential and parallel aggregate operations.  The following example
    illustrates an aggregate operation using the stream types Stream
    and IntStream, computing the sum of the weights of the red widgets:
    
    ````int sum = widgets.stream()
                         .filter(w -> w.getColor() == RED)
                         .mapToInt(w -> w.getWeight())
                         .sum();````
    
    See the class documentation for Stream and the package documentation
    for <a href="package-summary.html">java.util.stream</a> for additional
    specification of streams, stream operations, stream pipelines, and
    parallelism, which governs the behavior of all stream types.
    
    Type `<T>`: the type of the stream elements
    
    Type `<S>`: the type of the stream implementing `BaseStream`

    See
    - <a href="package-summary.html">java.util.stream</a>

    Since
    - 1.8
    """

    def iterator(self) -> Iterator["T"]:
        """
        Returns an iterator for the elements of this stream.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.

        Returns
        - the element iterator for this stream
        """
        ...


    def spliterator(self) -> "Spliterator"["T"]:
        """
        Returns a spliterator for the elements of this stream.
        
        This is a <a href="package-summary.html#StreamOps">terminal
        operation</a>.
        
        
        The returned spliterator should report the set of characteristics derived
        from the stream pipeline (namely the characteristics derived from the
        stream source spliterator and the intermediate operations).
        Implementations may report a sub-set of those characteristics.  For
        example, it may be too expensive to compute the entire set for some or
        all possible stream pipelines.

        Returns
        - the element spliterator for this stream
        """
        ...


    def isParallel(self) -> bool:
        """
        Returns whether this stream, if a terminal operation were to be executed,
        would execute in parallel.  Calling this method after invoking an
        terminal stream operation method may yield unpredictable results.

        Returns
        - `True` if this stream would execute in parallel if executed
        """
        ...


    def sequential(self) -> "S":
        """
        Returns an equivalent stream that is sequential.  May return
        itself, either because the stream was already sequential, or because
        the underlying stream state was modified to be sequential.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Returns
        - a sequential stream
        """
        ...


    def parallel(self) -> "S":
        """
        Returns an equivalent stream that is parallel.  May return
        itself, either because the stream was already parallel, or because
        the underlying stream state was modified to be parallel.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Returns
        - a parallel stream
        """
        ...


    def unordered(self) -> "S":
        """
        Returns an equivalent stream that is
        <a href="package-summary.html#Ordering">unordered</a>.  May return
        itself, either because the stream was already unordered, or because
        the underlying stream state was modified to be unordered.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Returns
        - an unordered stream
        """
        ...


    def onClose(self, closeHandler: "Runnable") -> "S":
        """
        Returns an equivalent stream with an additional close handler.  Close
        handlers are run when the .close() method
        is called on the stream, and are executed in the order they were
        added.  All close handlers are run, even if earlier close handlers throw
        exceptions.  If any close handler throws an exception, the first
        exception thrown will be relayed to the caller of `close()`, with
        any remaining exceptions added to that exception as suppressed exceptions
        (unless one of the remaining exceptions is the same exception as the
        first exception, since an exception cannot suppress itself.)  May
        return itself.
        
        This is an <a href="package-summary.html#StreamOps">intermediate
        operation</a>.

        Arguments
        - closeHandler: A task to execute when the stream is closed

        Returns
        - a stream with a handler that is run if the stream is closed
        """
        ...


    def close(self) -> None:
        """
        Closes this stream, causing all close handlers for this stream pipeline
        to be called.

        See
        - AutoCloseable.close()
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.composer.Composer

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Collections
from org.yaml.snakeyaml.DumperOptions import FlowStyle
from org.yaml.snakeyaml import LoaderOptions
from org.yaml.snakeyaml.comments import CommentEventsCollector
from org.yaml.snakeyaml.comments import CommentLine
from org.yaml.snakeyaml.comments import CommentType
from org.yaml.snakeyaml.composer import *
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.events import AliasEvent
from org.yaml.snakeyaml.events import Event
from org.yaml.snakeyaml.events import MappingStartEvent
from org.yaml.snakeyaml.events import NodeEvent
from org.yaml.snakeyaml.events import ScalarEvent
from org.yaml.snakeyaml.events import SequenceStartEvent
from org.yaml.snakeyaml.nodes import MappingNode
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.nodes import NodeId
from org.yaml.snakeyaml.nodes import NodeTuple
from org.yaml.snakeyaml.nodes import ScalarNode
from org.yaml.snakeyaml.nodes import SequenceNode
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.parser import Parser
from org.yaml.snakeyaml.resolver import Resolver
from typing import Any, Callable, Iterable, Tuple


class Composer:
    """
    Creates a node graph from parser events.
    
    Corresponds to the 'Compose' step as described in chapter 3.1 of the
    <a href="http://yaml.org/spec/1.1/">YAML Specification</a>.
    """

    def __init__(self, parser: "Parser", resolver: "Resolver", loadingConfig: "LoaderOptions"):
        """
        Create

        Arguments
        - parser: - the parser
        - resolver: - the resolver
        - loadingConfig: - options
        """
        ...


    def checkNode(self) -> bool:
        """
        Checks if further documents are available.

        Returns
        - `True` if there is at least one more document.
        """
        ...


    def getNode(self) -> "Node":
        """
        Reads and composes the next document.

        Returns
        - The root node of the document or `null` if no more documents are available.
        """
        ...


    def getSingleNode(self) -> "Node":
        """
        Reads a document from a source that contains only one document.
        
        If the stream contains more than one document an exception is thrown.

        Returns
        - The root node of the document or `null` if no document is available.
        """
        ...



"""
Python module generated from Java source file org.bukkit.potion.PotionEffect

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import ImmutableMap
from java.util import NoSuchElementException
from org.bukkit import Bukkit
from org.bukkit import Color
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.configuration.serialization import SerializableAs
from org.bukkit.entity import LivingEntity
from org.bukkit.potion import *
from typing import Any, Callable, Iterable, Tuple


class PotionEffect(ConfigurationSerializable):
    """
    Represents a potion effect, that can be added to a LivingEntity. A
    potion effect has a duration that it will last for, an amplifier that will
    enhance its effects, and a PotionEffectType, that represents its
    effect on an entity.
    """

    INFINITE_DURATION = -1
    """
    A constant denoting infinite potion duration.
    """


    def __init__(self, type: "PotionEffectType", duration: int, amplifier: int, ambient: bool, particles: bool, icon: bool):
        """
        Creates a potion effect.

        Arguments
        - type: effect type
        - duration: measured in ticks, see PotionEffect.getDuration()
        - amplifier: the amplifier, see PotionEffect.getAmplifier()
        - ambient: the ambient status, see PotionEffect.isAmbient()
        - particles: the particle status, see PotionEffect.hasParticles()
        - icon: the icon status, see PotionEffect.hasIcon()
        """
        ...


    def __init__(self, type: "PotionEffectType", duration: int, amplifier: int, ambient: bool, particles: bool):
        """
        Creates a potion effect with no defined color.

        Arguments
        - type: effect type
        - duration: measured in ticks, see PotionEffect.getDuration()
        - amplifier: the amplifier, see PotionEffect.getAmplifier()
        - ambient: the ambient status, see PotionEffect.isAmbient()
        - particles: the particle status, see PotionEffect.hasParticles()
        """
        ...


    def __init__(self, type: "PotionEffectType", duration: int, amplifier: int, ambient: bool):
        """
        Creates a potion effect. Assumes that particles are visible

        Arguments
        - type: effect type
        - duration: measured in ticks, see PotionEffect.getDuration()
        - amplifier: the amplifier, see PotionEffect.getAmplifier()
        - ambient: the ambient status, see PotionEffect.isAmbient()
        """
        ...


    def __init__(self, type: "PotionEffectType", duration: int, amplifier: int):
        """
        Creates a potion effect. Assumes ambient is True.

        Arguments
        - type: Effect type
        - duration: measured in ticks
        - amplifier: the amplifier for the effect

        See
        - PotionEffect.PotionEffect(PotionEffectType, int, int, boolean)
        """
        ...


    def __init__(self, map: dict[str, "Object"]):
        """
        Constructor for deserialization.

        Arguments
        - map: the map to deserialize from
        """
        ...


    def serialize(self) -> dict[str, "Object"]:
        ...


    def apply(self, entity: "LivingEntity") -> bool:
        """
        Attempts to add the effect represented by this object to the given
        LivingEntity.

        Arguments
        - entity: The entity to add this effect to

        Returns
        - Whether the effect could be added

        See
        - LivingEntity.addPotionEffect(PotionEffect)
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def getAmplifier(self) -> int:
        """
        Returns the amplifier of this effect. A higher amplifier means the
        potion effect happens more often over its duration and in some cases
        has more effect on its target.

        Returns
        - The effect amplifier
        """
        ...


    def getDuration(self) -> int:
        """
        Returns the duration (in ticks) that this effect will run for when
        applied to a LivingEntity.

        Returns
        - The duration of the effect, or .INFINITE_DURATION if
        this effect is infinite

        See
        - .isInfinite()
        """
        ...


    def isInfinite(self) -> bool:
        """
        Returns whether or not this potion effect has an infinite duration. Potion
        effects with infinite durations will display an infinite symbol and never
        expire unless manually removed.

        Returns
        - whether this duration is infinite or not
        """
        ...


    def isShorterThan(self, other: "PotionEffect") -> bool:
        """
        Returns whether or not this potion effect has a shorter duration than the
        provided potion effect.
        
        An infinite duration is considered longer than non-infinite durations. If
        both potion effects have infinite durations, then neither is shorter than
        the other and this method will return False.

        Arguments
        - other: the other effect

        Returns
        - True if this effect is shorter than the other, False if longer or equal
        """
        ...


    def getType(self) -> "PotionEffectType":
        """
        Returns the PotionEffectType of this effect.

        Returns
        - The potion type of this effect
        """
        ...


    def isAmbient(self) -> bool:
        """
        Makes potion effect produce more, translucent, particles.

        Returns
        - if this effect is ambient
        """
        ...


    def hasParticles(self) -> bool:
        """
        Returns
        - whether this effect has particles or not
        """
        ...


    def getColor(self) -> "Color":
        """
        Returns
        - color of this potion's particles. May be null if the potion has no particles or defined color.

        Deprecated
        - color is not part of potion effects
        """
        ...


    def hasIcon(self) -> bool:
        """
        Returns
        - whether this effect has an icon or not
        """
        ...


    def hashCode(self) -> int:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.eventbus.AsyncEventBus

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.eventbus import *
from java.util.concurrent import Executor
from typing import Any, Callable, Iterable, Tuple


class AsyncEventBus(EventBus):
    """
    An EventBus that takes the Executor of your choice and uses it to dispatch events,
    allowing dispatch to occur asynchronously.

    Author(s)
    - Cliff Biffle

    Since
    - 10.0
    """

    def __init__(self, identifier: str, executor: "Executor"):
        """
        Creates a new AsyncEventBus that will use `executor` to dispatch events. Assigns `identifier` as the bus's name for logging purposes.

        Arguments
        - identifier: short name for the bus, for logging purposes.
        - executor: Executor to use to dispatch events. It is the caller's responsibility to shut
            down the executor after the last event has been posted to this event bus.
        """
        ...


    def __init__(self, executor: "Executor", subscriberExceptionHandler: "SubscriberExceptionHandler"):
        """
        Creates a new AsyncEventBus that will use `executor` to dispatch events.

        Arguments
        - executor: Executor to use to dispatch events. It is the caller's responsibility to shut
            down the executor after the last event has been posted to this event bus.
        - subscriberExceptionHandler: Handler used to handle exceptions thrown from subscribers.
            See SubscriberExceptionHandler for more information.

        Since
        - 16.0
        """
        ...


    def __init__(self, executor: "Executor"):
        """
        Creates a new AsyncEventBus that will use `executor` to dispatch events.

        Arguments
        - executor: Executor to use to dispatch events. It is the caller's responsibility to shut
            down the executor after the last event has been posted to this event bus.
        """
        ...



"""
Python module generated from Java source file org.bukkit.Nameable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Nameable:
    """
    Represents a block, entity, or other object that may receive a custom name.
    """

    def getCustomName(self) -> str:
        """
        Gets the custom name on a mob or block. If there is no name this method
        will return null.
        
        This value has no effect on players, they will always use their real
        name.

        Returns
        - name of the mob/block or null
        """
        ...


    def setCustomName(self, name: str) -> None:
        """
        Sets a custom name on a mob or block. This name will be used in death
        messages and can be sent to the client as a nameplate over the mob.
        
        Setting the name to null or an empty string will clear it.
        
        This value has no effect on players, they will always use their real
        name.

        Arguments
        - name: the name to set
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.$Gson$Preconditions

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class $Gson$Preconditions:
    """
    A simple utility class used to check method Preconditions.
    
    ```
    public long divideBy(long value) {
      Preconditions.checkArgument(value != 0);
      return this.value / value;
    }
    ```

    Author(s)
    - Joel Leitch
    """

    @staticmethod
    def checkNotNull(obj: "T") -> "T":
        ...


    @staticmethod
    def checkArgument(condition: bool) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.util.noise.NoiseGenerator

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.util.noise import *
from typing import Any, Callable, Iterable, Tuple


class NoiseGenerator:
    """
    Base class for all noise generators
    """

    @staticmethod
    def floor(x: float) -> int:
        """
        Speedy floor, faster than (int)Math.floor(x)

        Arguments
        - x: Value to floor

        Returns
        - Floored value
        """
        ...


    def noise(self, x: float) -> float:
        """
        Computes and returns the 1D noise for the given coordinate in 1D space

        Arguments
        - x: X coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    def noise(self, x: float, y: float) -> float:
        """
        Computes and returns the 2D noise for the given coordinates in 2D space

        Arguments
        - x: X coordinate
        - y: Y coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    def noise(self, x: float, y: float, z: float) -> float:
        """
        Computes and returns the 3D noise for the given coordinates in 3D space

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    def noise(self, x: float, octaves: int, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 1D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, octaves: int, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 1D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, octaves: int, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 2D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, octaves: int, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 2D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, z: float, octaves: int, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, z: float, octaves: int, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - octaves: Number of octaves to use
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...



from .BlockDataMeta import BlockDataMeta
from .CrossbowMeta import CrossbowMeta
from .ShieldMeta import ShieldMeta
from .OminousBottleMeta import OminousBottleMeta
from .KnowledgeBookMeta import KnowledgeBookMeta
from .BookMeta import BookMeta
from .EnchantmentStorageMeta import EnchantmentStorageMeta
from .SuspiciousStewMeta import SuspiciousStewMeta
from .WritableBookMeta import WritableBookMeta
from .SpawnEggMeta import SpawnEggMeta
from .BlockStateMeta import BlockStateMeta
from .ItemMeta import ItemMeta
from .MapMeta import MapMeta
from .BundleMeta import BundleMeta
from .TropicalFishBucketMeta import TropicalFishBucketMeta
from .CompassMeta import CompassMeta
from .BannerMeta import BannerMeta
from .Repairable import Repairable
from .Damageable import Damageable
from .SkullMeta import SkullMeta
from .AxolotlBucketMeta import AxolotlBucketMeta
from .FireworkEffectMeta import FireworkEffectMeta
from .ArmorMeta import ArmorMeta
from .MusicInstrumentMeta import MusicInstrumentMeta
from .PotionMeta import PotionMeta
from .LeatherArmorMeta import LeatherArmorMeta
from .ColorableArmorMeta import ColorableArmorMeta
from .FireworkMeta import FireworkMeta


"""
Python module generated from Java source file org.bukkit.inventory.view.BrewingStandView

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import BrewerInventory
from org.bukkit.inventory import InventoryView
from org.bukkit.inventory.view import *
from typing import Any, Callable, Iterable, Tuple


class BrewingStandView(InventoryView):
    """
    An instance of InventoryView which provides extra methods related to
    brewing stand view data.
    """

    def getTopInventory(self) -> "BrewerInventory":
        ...


    def getFuelLevel(self) -> int:
        """
        Gets the fuel level of this brewing stand.
        
        The default maximum fuel level in minecraft is 20.

        Returns
        - The amount of fuel level left
        """
        ...


    def getBrewingTicks(self) -> int:
        """
        Gets the amount of brewing ticks left.

        Returns
        - The amount of ticks left for the brewing task
        """
        ...


    def setFuelLevel(self, level: int) -> None:
        """
        Sets the fuel level left.

        Arguments
        - level: the level of the fuel, which is no less than 0

        Raises
        - IllegalArgumentException: if the level is less than 0
        """
        ...


    def setBrewingTicks(self, ticks: int) -> None:
        """
        Sets the brewing ticks left.

        Arguments
        - ticks: the ticks left, which is no less than 0

        Raises
        - IllegalArgumentException: if the ticks are less than 0
        """
        ...



"""
Python module generated from Java source file com.google.gson.JsonIOException

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from typing import Any, Callable, Iterable, Tuple


class JsonIOException(JsonParseException):
    """
    This exception is raised when Gson was unable to read an input stream or write to one.

    Author(s)
    - Joel Leitch
    """

    def __init__(self, msg: str):
        ...


    def __init__(self, msg: str, cause: "Throwable"):
        ...


    def __init__(self, cause: "Throwable"):
        """
        Creates exception with the specified cause. Consider using .JsonIOException(String,
        Throwable) instead if you can describe what happened.

        Arguments
        - cause: root exception that caused this exception to be thrown.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerKickEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerKickEvent(PlayerEvent, Cancellable):
    """
    Called when a player gets kicked from the server
    """

    def __init__(self, playerKicked: "Player", kickReason: str, leaveMessage: str):
        ...


    def getReason(self) -> str:
        """
        Gets the reason why the player is getting kicked

        Returns
        - string kick reason
        """
        ...


    def getLeaveMessage(self) -> str:
        """
        Gets the leave message send to all online players

        Returns
        - string kick reason
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def setReason(self, kickReason: str) -> None:
        """
        Sets the reason why the player is getting kicked

        Arguments
        - kickReason: kick reason
        """
        ...


    def setLeaveMessage(self, leaveMessage: str) -> None:
        """
        Sets the leave message send to all online players

        Arguments
        - leaveMessage: leave message
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.JsonElement

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.gson import *
from com.google.gson.internal import Streams
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.io import Reader
from java.io import StringWriter
from java.math import BigDecimal
from java.math import BigInteger
from typing import Any, Callable, Iterable, Tuple


class JsonElement:
    """
    A class representing an element of JSON. It could either be a JsonObject, a JsonArray, a JsonPrimitive or a JsonNull.
    
    This class provides multiple `getAs` methods which allow
    
    
      - obtaining the represented primitive value, for example .getAsString()
      - casting to the `JsonElement` subclasses in a convenient way, for example .getAsJsonObject()
    
    
    <h2>Converting `JsonElement` from / to JSON</h2>
    
    There are two ways to parse JSON data as a JsonElement:
    
    
      - JsonParser, for example:
          ```
    JsonObject jsonObject = JsonParser.parseString("{}").getAsJsonObject();
    ```
      - Gson.fromJson(Reader, Class) Gson.fromJson(..., JsonElement.class)
          It is possible to directly specify a `JsonElement` subclass, for example:
          ```
    JsonObject jsonObject = gson.fromJson("{}", JsonObject.class);
    ```
    
    
    To convert a `JsonElement` to JSON either .toString() JsonElement.toString() or the
    method Gson.toJson(JsonElement) and its overloads can be used.
    
    It is also possible to obtain the TypeAdapter for `JsonElement` from a Gson instance and then use it for conversion from and to JSON:
    
    ````TypeAdapter<JsonElement> adapter = gson.getAdapter(JsonElement.class);
    
    JsonElement value = adapter.fromJson("{`");
    String json = adapter.toJson(value);
    }```
    
    <h2>`JsonElement` as JSON data</h2>
    
    `JsonElement` can also be treated as JSON data, allowing to deserialize from a `JsonElement` and serializing to a `JsonElement`. The Gson class offers these
    methods for this:
    
    
      - Gson.fromJson(JsonElement, Class) Gson.fromJson(JsonElement, ...), for example:
          ```
    JsonObject jsonObject = ...;
    MyClass myObj = gson.fromJson(jsonObject, MyClass.class);
    ```
      - Gson.toJsonTree(Object), for example:
          ```
    MyClass myObj = ...;
    JsonElement json = gson.toJsonTree(myObj);
    ```
    
    
    The TypeAdapter class provides corresponding methods as well:
    
    
      - TypeAdapter.fromJsonTree(JsonElement)
      - TypeAdapter.toJsonTree(Object)

    Author(s)
    - Joel Leitch
    """

    def __init__(self):
        """
        Deprecated
        - Creating custom `JsonElement` subclasses is highly discouraged and can lead
            to undefined behavior.
            This constructor is only kept for backward compatibility.
        """
        ...


    def deepCopy(self) -> "JsonElement":
        """
        Returns a deep copy of this element. Immutable elements like primitives and nulls are not
        copied.

        Since
        - 2.8.2
        """
        ...


    def isJsonArray(self) -> bool:
        """
        Provides a check for verifying if this element is a JSON array or not.

        Returns
        - True if this element is of type JsonArray, False otherwise.
        """
        ...


    def isJsonObject(self) -> bool:
        """
        Provides a check for verifying if this element is a JSON object or not.

        Returns
        - True if this element is of type JsonObject, False otherwise.
        """
        ...


    def isJsonPrimitive(self) -> bool:
        """
        Provides a check for verifying if this element is a primitive or not.

        Returns
        - True if this element is of type JsonPrimitive, False otherwise.
        """
        ...


    def isJsonNull(self) -> bool:
        """
        Provides a check for verifying if this element represents a null value or not.

        Returns
        - True if this element is of type JsonNull, False otherwise.

        Since
        - 1.2
        """
        ...


    def getAsJsonObject(self) -> "JsonObject":
        """
        Convenience method to get this element as a JsonObject. If this element is of some
        other type, an IllegalStateException will result. Hence it is best to use this method
        after ensuring that this element is of the desired type by calling .isJsonObject()
        first.

        Returns
        - this element as a JsonObject.

        Raises
        - IllegalStateException: if this element is of another type.
        """
        ...


    def getAsJsonArray(self) -> "JsonArray":
        """
        Convenience method to get this element as a JsonArray. If this element is of some other
        type, an IllegalStateException will result. Hence it is best to use this method after
        ensuring that this element is of the desired type by calling .isJsonArray() first.

        Returns
        - this element as a JsonArray.

        Raises
        - IllegalStateException: if this element is of another type.
        """
        ...


    def getAsJsonPrimitive(self) -> "JsonPrimitive":
        """
        Convenience method to get this element as a JsonPrimitive. If this element is of some
        other type, an IllegalStateException will result. Hence it is best to use this method
        after ensuring that this element is of the desired type by calling .isJsonPrimitive()
        first.

        Returns
        - this element as a JsonPrimitive.

        Raises
        - IllegalStateException: if this element is of another type.
        """
        ...


    def getAsJsonNull(self) -> "JsonNull":
        """
        Convenience method to get this element as a JsonNull. If this element is of some other
        type, an IllegalStateException will result. Hence it is best to use this method after
        ensuring that this element is of the desired type by calling .isJsonNull() first.

        Returns
        - this element as a JsonNull.

        Raises
        - IllegalStateException: if this element is of another type.

        Since
        - 1.2
        """
        ...


    def getAsBoolean(self) -> bool:
        """
        Convenience method to get this element as a boolean value.

        Returns
        - this element as a primitive boolean value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsNumber(self) -> "Number":
        """
        Convenience method to get this element as a Number.

        Returns
        - this element as a Number.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray, or cannot be converted to a number.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsString(self) -> str:
        """
        Convenience method to get this element as a string value.

        Returns
        - this element as a string value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsDouble(self) -> float:
        """
        Convenience method to get this element as a primitive double value.

        Returns
        - this element as a primitive double value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if the value contained is not a valid double.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsFloat(self) -> float:
        """
        Convenience method to get this element as a primitive float value.

        Returns
        - this element as a primitive float value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if the value contained is not a valid float.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsLong(self) -> int:
        """
        Convenience method to get this element as a primitive long value.

        Returns
        - this element as a primitive long value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if the value contained is not a valid long.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsInt(self) -> int:
        """
        Convenience method to get this element as a primitive integer value.

        Returns
        - this element as a primitive integer value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if the value contained is not a valid integer.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def getAsByte(self) -> int:
        """
        Convenience method to get this element as a primitive byte value.

        Returns
        - this element as a primitive byte value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if the value contained is not a valid byte.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.

        Since
        - 1.3
        """
        ...


    def getAsCharacter(self) -> str:
        """
        Convenience method to get the first character of the string value of this element.

        Returns
        - the first character of the string value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray, or if its string value is empty.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.

        Since
        - 1.3

        Deprecated
        - This method is misleading, as it does not get this element as a char but rather as
            a string's first character.
        """
        ...


    def getAsBigDecimal(self) -> "BigDecimal":
        """
        Convenience method to get this element as a BigDecimal.

        Returns
        - this element as a BigDecimal.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if this element is not a valid BigDecimal.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.

        Since
        - 1.2
        """
        ...


    def getAsBigInteger(self) -> "BigInteger":
        """
        Convenience method to get this element as a BigInteger.

        Returns
        - this element as a BigInteger.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if this element is not a valid BigInteger.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.

        Since
        - 1.2
        """
        ...


    def getAsShort(self) -> int:
        """
        Convenience method to get this element as a primitive short value.

        Returns
        - this element as a primitive short value.

        Raises
        - UnsupportedOperationException: if this element is not a JsonPrimitive or JsonArray.
        - NumberFormatException: if the value contained is not a valid short.
        - IllegalStateException: if this element is of the type JsonArray but contains
            more than a single element.
        """
        ...


    def toString(self) -> str:
        """
        Converts this element to a JSON string.
        
        For example:
        
        ```
        JsonObject object = new JsonObject();
        object.add("a", JsonNull.INSTANCE);
        JsonArray array = new JsonArray();
        array.add(1);
        object.add("b", array);
        
        String json = object.toString();
        // json: {"a":null,"b":[1]}
        ```
        
        If this element or any nested elements contain Double.NaN NaN or Double.isInfinite() Infinity that value is written to JSON, even though the JSON specification
        does not permit these values.
        
        To customize formatting or to directly write to an Appendable instead of creating an
        intermediate `String` first, use Gson.toJson(JsonElement, Appendable)
        Gson.toJson(JsonElement, ...).
        
        To get the contained String value (without enclosing `"` and without escaping), use
        .getAsString() instead:
        
        ```
        JsonPrimitive jsonPrimitive = new JsonPrimitive("with \" quote");
        String json = jsonPrimitive.toString();
        // json: "with \" quote"
        String value = jsonPrimitive.getAsString();
        // value: with " quote
        ```
        """
        ...



"""
Python module generated from Java source file com.google.common.primitives.Primitives

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.primitives import *
from java.util import Collections
from typing import Any, Callable, Iterable, Tuple


class Primitives:
    """
    Contains static utility methods pertaining to primitive types and their corresponding wrapper
    types.

    Author(s)
    - Kevin Bourrillion

    Since
    - 1.0
    """

    @staticmethod
    def allPrimitiveTypes() -> set[type[Any]]:
        """
        Returns an immutable set of all nine primitive types (including `void`). Note that a
        simpler way to test whether a `Class` instance is a member of this set is to call Class.isPrimitive.

        Since
        - 3.0
        """
        ...


    @staticmethod
    def allWrapperTypes() -> set[type[Any]]:
        """
        Returns an immutable set of all nine primitive-wrapper types (including Void).

        Since
        - 3.0
        """
        ...


    @staticmethod
    def isWrapperType(type: type[Any]) -> bool:
        """
        Returns `True` if `type` is one of the nine primitive-wrapper types, such as Integer.

        See
        - Class.isPrimitive
        """
        ...


    @staticmethod
    def wrap(type: type["T"]) -> type["T"]:
        """
        Returns the corresponding wrapper type of `type` if it is a primitive type; otherwise
        returns `type` itself. Idempotent.
        
        ```
            wrap(int.class) == Integer.class
            wrap(Integer.class) == Integer.class
            wrap(String.class) == String.class
        ```
        """
        ...


    @staticmethod
    def unwrap(type: type["T"]) -> type["T"]:
        """
        Returns the corresponding primitive type of `type` if it is a wrapper type; otherwise
        returns `type` itself. Idempotent.
        
        ```
            unwrap(Integer.class) == int.class
            unwrap(int.class) == int.class
            unwrap(String.class) == String.class
        ```
        """
        ...
